@@ -1,6 +1,3 @@
-# (C) John Mair (banisterfiend) 2016
-# MIT License
-#
 require 'pp'
 require 'pry/forwardable'
 require 'pry/input_lock'
@@ -13,6 +10,7 @@ class Pry
   # The default hooks - display messages when beginning and ending Pry sessions.
   DEFAULT_HOOKS = Pry::Hooks.new.add_hook(:before_session, :default) do |out, target, _pry_|
     next if _pry_.quiet?
+
     _pry_.run_command("whereami --quiet")
   end
 
@@ -46,47 +44,18 @@ class Pry
     else
       output.puts "#{exception.class}: #{exception.message}"
       output.puts "from #{exception.backtrace.first}"
+
+      if exception.respond_to? :cause
+        cause = exception.cause
+        while cause
+          output.puts "Caused by #{cause.class}: #{cause}\n"
+          output.puts "from #{cause.backtrace.first}"
+          cause = cause.cause
+        end
+      end
     end
   end
 
-  DEFAULT_PROMPT_NAME = 'pry'
-
-  # The default prompt; includes the target and nesting level
-  DEFAULT_PROMPT = [
-                    proc { |target_self, nest_level, pry|
-                      "[#{pry.input_array.size}] #{pry.config.prompt_name}(#{Pry.view_clip(target_self)})#{":#{nest_level}" unless nest_level.zero?}> "
-                    },
-
-                    proc { |target_self, nest_level, pry|
-                      "[#{pry.input_array.size}] #{pry.config.prompt_name}(#{Pry.view_clip(target_self)})#{":#{nest_level}" unless nest_level.zero?}* "
-                    }
-                   ]
-
-  DEFAULT_PROMPT_SAFE_OBJECTS = [String, Numeric, Symbol, nil, true, false]
-
-  # A simple prompt - doesn't display target or nesting level
-  SIMPLE_PROMPT = [proc { ">> " }, proc { " | " }]
-
-  NO_PROMPT = [proc { '' }, proc { '' }]
-
-  SHELL_PROMPT = [
-                  proc { |target_self, _, _pry_| "#{_pry_.config.prompt_name} #{Pry.view_clip(target_self)}:#{Dir.pwd} $ " },
-                  proc { |target_self, _, _pry_| "#{_pry_.config.prompt_name} #{Pry.view_clip(target_self)}:#{Dir.pwd} * " }
-                 ]
-
-  # A prompt that includes the full object path as well as
-  # input/output (_in_ and _out_) information. Good for navigation.
-  NAV_PROMPT = [
-                proc do |_, _, _pry_|
-                  tree = _pry_.binding_stack.map { |b| Pry.view_clip(b.eval("self")) }.join " / "
-                  "[#{_pry_.input_array.count}] (#{_pry_.config.prompt_name}) #{tree}: #{_pry_.binding_stack.size - 1}> "
-                end,
-                proc do |_, _, _pry_|
-                  tree = _pry_.binding_stack.map { |b| Pry.view_clip(b.eval("self")) }.join " / "
-                  "[#{_pry_.input_array.count}] (#{ _pry_.config.prompt_name}) #{tree}: #{_pry_.binding_stack.size - 1}* "
-                end,
-               ]
-
   # Deal with the ^D key being pressed. Different behaviour in different cases:
   #   1. In an expression behave like `!` command.
   #   2. At top-level session behave like `exit` command.
@@ -112,10 +81,6 @@ class Pry
     end
   end
 
-  # Store the current working directory. This allows show-source etc. to work if
-  # your process has changed directory since boot. [Issue #675]
-  INITIAL_PWD = Dir.pwd
-
   # This is to keep from breaking under Rails 3.2 for people who are doing that
   # IRB = Pry thing.
   module ExtendCommandBundle; end
@@ -133,9 +98,8 @@ require 'pathname'
 
 require 'pry/version'
 require 'pry/repl'
-require 'pry/rbx_path'
 require 'pry/code'
-require 'pry/history_array'
+require 'pry/ring'
 require 'pry/helpers'
 require 'pry/code_object'
 require 'pry/method'
@@ -146,6 +110,12 @@ require 'pry/command_set'
 require 'pry/commands'
 require 'pry/plugins'
 require 'pry/core_extensions'
+require 'pry/basic_object'
+require 'pry/config/behavior'
+require 'pry/config/memoization'
+require 'pry/config/default'
+require 'pry/config/convenience'
+require 'pry/config'
 require 'pry/pry_class'
 require 'pry/pry_instance'
 require 'pry/cli'
