@@ -1,12 +1,9 @@
 class Pry
-
   # Manage the processing of command line options
   class CLI
-
     NoOptionsError = Class.new(StandardError)
 
     class << self
-
       # @return [Proc] The Proc defining the valid command line options.
       attr_accessor :options
 
@@ -57,22 +54,19 @@ class Pry
         self.option_processors = nil
       end
 
-      def parse_options(args=ARGV)
+      def parse_options(args = ARGV)
         unless options
           raise NoOptionsError, "No command line options defined! Use Pry::CLI.add_options to add command line options."
         end
 
-        # Load config files etc first, ensuring that cli options will take precedence.
-        Pry.initial_session_setup
-
         self.input_args = args
 
         begin
           opts = Pry::Slop.parse!(
             args,
-            :help => true,
-            :multiple_switches => false,
-            :strict => true,
+            help: true,
+            multiple_switches: false,
+            strict: true,
             &options
           )
         rescue Pry::Slop::InvalidOptionError
@@ -81,6 +75,7 @@ class Pry
           exit
         end
 
+        Pry.initial_session_setup
         Pry.final_session_setup
 
         # Option processors are optional.
@@ -113,16 +108,14 @@ class Pry
         end
 
         # Start the session (running any code passed with -e, if there is any)
-        Pry.start(context, :input => StringIO.new(Pry.config.exec_string))
+        Pry.start(context, input: StringIO.new(Pry.config.exec_string))
       end
-
     end
 
     reset
   end
 end
 
-
 # Bring in options defined by plugins
 Pry::Slop.new do
   on "no-plugins" do
@@ -136,12 +129,12 @@ end
 
 # The default Pry command line options (before plugin options are included)
 Pry::CLI.add_options do
-  banner %{Usage: pry [OPTIONS]
-Start a Pry session.
-See http://pryrepl.org/ for more information.
-Copyright (c) 2016 John Mair (banisterfiend)
---
-}
+  banner(
+    "Usage: pry [OPTIONS]\n" \
+    "Start a Pry session.\n" \
+    "See http://pryrepl.org/ for more information.\n"
+  )
+
   on :e, :exec=, "A line of code to execute in context before the session starts" do |input|
     Pry.config.exec_string += "\n" if Pry.config.exec_string.length > 0
     Pry.config.exec_string += input
@@ -159,7 +152,7 @@ Copyright (c) 2016 John Mair (banisterfiend)
     Pry.config.color = false
   end
 
-  on :f, "Suppress loading of ~/.pryrc and ./.pryrc" do
+  on :f, "Suppress loading of pryrc" do
     Pry.config.should_load_rc = false
     Pry.config.should_load_local_rc = false
   end
@@ -187,18 +180,18 @@ Copyright (c) 2016 John Mair (banisterfiend)
   end
 
   on "simple-prompt", "Enable simple prompt mode" do
-    Pry.config.prompt = Pry::SIMPLE_PROMPT
+    Pry.config.prompt = Pry::Prompt[:simple][:value]
   end
 
   on "noprompt", "No prompt mode" do
-    Pry.config.prompt = Pry::NO_PROMPT
+    Pry.config.prompt = Pry::Prompt[:none][:value]
   end
 
   on :r, :require=, "`require` a Ruby script at startup" do |file|
     Pry.config.requires << file
   end
 
-  on :I=, "Add a path to the $LOAD_PATH", :as => Array, :delimiter => ":" do |load_path|
+  on :I=, "Add a path to the $LOAD_PATH", as: Array, delimiter: ":" do |load_path|
     load_path.map! do |path|
       /\A\.\// =~ path ? path : File.expand_path(path)
     end
@@ -220,6 +213,6 @@ Copyright (c) 2016 John Mair (banisterfiend)
 
   on(:c, :context=,
      "Start the session in the specified context. Equivalent to `context.pry` in a session.",
-     :default => "Pry.toplevel_binding"
+     default: "Pry.toplevel_binding"
      )
 end
