@@ -1,5 +1,4 @@
 class Pry
-
   # This class is responsible for taking a string (identifying a
   # command/class/method/etc) and returning the relevant type of object.
   # For example, if the user looks up "show-source" then  a
@@ -64,7 +63,7 @@ class Pry
     include Pry::Helpers::CommandHelpers
 
     class << self
-      def lookup(str, _pry_, options={})
+      def lookup(str, _pry_, options = {})
         co = new(str, _pry_, options)
 
         co.default_lookup || co.method_or_class_lookup ||
@@ -77,9 +76,9 @@ class Pry
     attr_accessor :_pry_
     attr_accessor :super_level
 
-    def initialize(str, _pry_, options={})
+    def initialize(str, _pry_, options = {})
       options = {
-        :super => 0,
+        super: 0,
       }.merge!(options)
 
       @str = str
@@ -170,6 +169,7 @@ class Pry
     def safe_to_evaluate?(str)
       return true if str.strip == "self"
       return false if str =~ /%/
+
       kind = target.eval("defined?(#{str})")
       kind =~ /variable|constant/
     end
