@@ -8,7 +8,7 @@ class Pry
       def decorate(content)
         content.code_type = code_type
         content.between(*between_lines).
-          with_line_numbers(use_line_numbers?)
+          with_line_numbers(use_line_numbers?).highlighted
       end
 
       def code_type
