@@ -20,7 +20,7 @@ class Pry
 
           content
         else
-          decorate(Pry::Code(selected_input_items.first)).to_s
+          decorate(Pry::Code(selected_input_items.first))
         end
       end
 
@@ -36,7 +36,7 @@ class Pry
       end
 
       def normalized_expression_range
-        absolute_index_range(opts[:i], input_expressions.length)
+        absolute_index_range(opts[:i], input_expressions.count)
       end
     end
   end
