@@ -9,7 +9,7 @@ class Pry
 
       Move into new context (object or scope). As in UNIX shells use `cd ..` to go
       back, `cd /` to return to Pry top-level and `cd -` to toggle between last two
-      scopes. Complex syntax (e.g `cd ../@x/y`) also supported.
+      scopes. Complex syntax (e.g `cd ../@x/@y`) also supported.
 
       cd @x
       cd ..
@@ -21,8 +21,19 @@ class Pry
 
     def process
       state.old_stack ||= []
-      stack, state.old_stack = context_from_object_path(arg_string, _pry_, state.old_stack)
-      _pry_.binding_stack = stack if stack
+
+      if arg_string.strip == "-"
+        unless state.old_stack.empty?
+          _pry_.binding_stack, state.old_stack = state.old_stack, _pry_.binding_stack
+        end
+      else
+        stack = ObjectPath.new(arg_string, _pry_.binding_stack).resolve
+
+        if stack && stack != _pry_.binding_stack
+          state.old_stack = _pry_.binding_stack
+          _pry_.binding_stack = stack
+        end
+      end
     end
   end
 
