@@ -29,17 +29,17 @@ class Pry
       @output_result_ranges = []
 
       opt.on :l, :lines, "Restrict to a subset of lines. Takes a line number or range",
-                         :optional_argument => true, :as => Range, :default => 1..-1
+                         optional_argument: true, as: Range, default: 1..-1
       opt.on :o, :out,   "Select lines from Pry's output result history. Takes an index or range",
-      :optional_argument => true, :as => Range, :default => -5..-1 do |r|
+      optional_argument: true, as: Range, default: -5..-1 do |r|
         output_result_ranges << (r || (-5..-1))
       end
       opt.on :i, :in,    "Select lines from Pry's input expression history. Takes an index or range",
-      :optional_argument => true, :as => Range, :default => -5..-1 do |r|
+      optional_argument: true, as: Range, default: -5..-1 do |r|
         input_expression_ranges << (r || (-5..-1))
       end
       opt.on :s, :super, "Select the 'super' method. Can be repeated to traverse the ancestors",
-                         :as => :count
+                         as: :count
       opt.on :d, :doc,   "Select lines from the code object's documentation"
     end
 
@@ -74,7 +74,7 @@ class Pry
     #
     # @return [Pry::WrappedModule, Pry::Method, Pry::Command]
     def code_object
-      Pry::CodeObject.lookup(obj_name, _pry_,  :super =>  opts[:super])
+      Pry::CodeObject.lookup(obj_name, _pry_, super: opts[:super])
     end
 
     # Given a string and a range, return the `range` lines of that
@@ -87,22 +87,22 @@ class Pry
       Array(content.lines.to_a[range]).join
     end
 
-    # The selected `_pry_.output_array` as a string, as specified by
+    # The selected `_pry_.output_ring` as a string, as specified by
     # the `-o` switch.
     #
     # @return [String]
     def pry_output_content
-      pry_array_content_as_string(_pry_.output_array, self.class.output_result_ranges) do |v|
+      pry_array_content_as_string(_pry_.output_ring, self.class.output_result_ranges) do |v|
         _pry_.config.gist.inspecter.call(v)
       end
     end
 
-    # The selected `_pry_.input_array` as a string, as specified by
+    # The selected `_pry_.input_ring` as a string, as specified by
     # the `-i` switch.
     #
     # @return [String]
     def pry_input_content
-      pry_array_content_as_string(_pry_.input_array, self.class.input_expression_ranges) { |v| v }
+      pry_array_content_as_string(_pry_.input_ring, self.class.input_expression_ranges) { |v| v }
     end
 
     # The line range passed to `--lines`, converted to a 0-indexed range.
