@@ -3,7 +3,7 @@ class Pry
     match 'gist'
     group 'Misc'
     description 'Upload code, docs, history to https://gist.github.com/.'
-    command_options :requires_gem => "gist"
+    command_options requires_gem: "gist"
 
     banner <<-'BANNER'
       Usage: gist [OPTIONS] [--help]
@@ -22,12 +22,13 @@ class Pry
     def options(opt)
       CodeCollector.inject_options(opt)
       opt.on :login, "Authenticate the gist gem with GitHub"
-      opt.on :p, :public, "Create a public gist (default: false)", :default => false
-      opt.on :clip, "Copy the selected content to clipboard instead, do NOT gist it", :default => false
+      opt.on :p, :public, "Create a public gist (default: false)", default: false
+      opt.on :clip, "Copy the selected content to clipboard instead, do NOT gist it", default: false
     end
 
     def process
       return ::Gist.login! if opts.present?(:login)
+
       cc = CodeCollector.new(args, opts, _pry_)
 
       if cc.content =~ /\A\s*\z/
@@ -52,13 +53,13 @@ class Pry
     def input_content
       content = ""
       CodeCollector.input_expression_ranges.each do |range|
-        input_expressions = _pry_.input_array[range] || []
+        input_expressions = _pry_.input_ring[range] || []
         Array(input_expressions).each_with_index do |code, index|
           corrected_index = index + range.first
           if code && code != ""
             content << code
             if code !~ /;\Z/
-              content << "#{comment_expression_result_for_gist(_pry_.config.gist.inspecter.call(_pry_.output_array[corrected_index]))}"
+              content << "#{comment_expression_result_for_gist(_pry_.config.gist.inspecter.call(_pry_.output_ring[corrected_index]))}"
             end
           end
         end
@@ -81,7 +82,7 @@ class Pry
     end
 
     def gist_content(content, filename)
-      response = ::Gist.gist(content, :filename => filename || "pry_gist.rb", :public => !!opts[:p])
+      response = ::Gist.gist(content, filename: filename || "pry_gist.rb", public: !!opts[:p])
       if response
         url = response['html_url']
         message = "Gist created at URL #{url}"
