@@ -59,7 +59,7 @@ class Pry
     # @param [Array<Pry::Command>] commands
     # @return [String] The generated help string.
     def help_text_for_commands(name, commands)
-      "#{text.bold(name.capitalize)}\n" << commands.map do |command|
+      "#{bold(name.capitalize)}\n" << commands.map do |command|
         "  #{command.options[:listing].to_s.ljust(18)} #{command.description.capitalize}"
       end.join("\n")
     end
@@ -75,14 +75,14 @@ class Pry
     # @param [Array<Pry::Command>] commands The commands to sort
     # @return [Array<Pry::Command>] commands sorted by listing name.
     def sorted_commands(commands)
-      commands.sort_by{ |command| command.options[:listing].to_s }
+      commands.sort_by { |command| command.options[:listing].to_s }
     end
 
     # Display help for an individual command or group.
     #
     # @param [String] search  The string to search for.
     def display_search(search)
-      if command = command_set.find_command_for_help(search)
+      if (command = command_set.find_command_for_help(search))
         display_command(command)
       else
         display_filtered_search_results(search)
