@@ -12,6 +12,7 @@ class Pry
 
       def write_out
         return false unless correct_opts?
+
         output_self
       end
 
@@ -25,8 +26,9 @@ class Pry
       # Outputs nothing if the section would be empty.
       def output_section(heading, body)
         return '' if body.compact.empty?
+
         fancy_heading = Pry::Helpers::Text.bold(color(:heading, heading))
-        Pry::Helpers.tablify_or_one_line(fancy_heading, body)
+        Pry::Helpers.tablify_or_one_line(fancy_heading, body, @_pry_.config)
       end
 
       def format_value(value)
@@ -44,7 +46,6 @@ class Pry
       def grep
         @grep || proc { |x| x }
       end
-
     end
   end
 end
