@@ -1,10 +1,10 @@
 class Pry
   # N.B. using a regular expresion here so that "raise-up 'foo'" does the right thing.
   class Command::RaiseUp < Pry::ClassCommand
-    match /raise-up(!?\b.*)/
+    match(/raise-up(!?\b.*)/)
     group 'Context'
     description 'Raise an exception out of the current pry instance.'
-    command_options :listing => 'raise-up'
+    command_options listing: 'raise-up'
 
     banner <<-BANNER
       Raise up, like exit, allows you to quit pry. Instead of returning a value
@@ -22,7 +22,8 @@ class Pry
     BANNER
 
     def process
-      return stagger_output help if captures[0] =~ /(-h|--help)\b/
+      return _pry.pager.page help if captures[0] =~ /(-h|--help)\b/
+
       # Handle 'raise-up', 'raise-up "foo"', 'raise-up RuntimeError, 'farble' in a rubyesque manner
       target.eval("_pry_.raise_up#{captures[0]}")
     end
