@@ -9,15 +9,13 @@ class Pry
     BANNER
 
     def process
-      case _pry_.prompt
-      when Pry::SHELL_PROMPT
-        _pry_.pop_prompt
-        _pry_.custom_completions = Pry::DEFAULT_CUSTOM_COMPLETIONS
+      state.disabled ^= true
+
+      if state.disabled
+        state.prev_prompt = _pry_.prompt
+        _pry_.prompt = Pry::Prompt[:shell][:value]
       else
-        _pry_.push_prompt Pry::SHELL_PROMPT
-        _pry_.custom_completions = Pry::FILE_COMPLETIONS
-        Readline.completion_proc = Pry::InputCompleter.build_completion_proc target,
-        _pry_.instance_eval(&Pry::FILE_COMPLETIONS)
+        _pry_.prompt = state.prev_prompt
       end
     end
   end
