@@ -1,6 +1,5 @@
 class Pry
   class Command::Whereami < Pry::ClassCommand
-
     def initialize(*)
       super
 
@@ -94,7 +93,7 @@ class Pry
 
       set_file_and_dir_locals(@file)
 
-      out = "\n#{text.bold('From:')} #{location}:\n\n" <<
+      out = "\n#{bold('From:')} #{location}:\n\n" <<
         code.with_line_numbers(use_line_numbers?).with_marker(marker).highlighted << "\n"
 
       _pry_.pager.page out
@@ -154,8 +153,9 @@ class Pry
     # or it returns the class of `target_self` if `target_self` is not a class.
     # @return [Pry::WrappedModule]
     def target_class
-      target_self.is_a?(Module) ? Pry::WrappedModule(target_self) :
-        Pry::WrappedModule(target_self.class)
+      return Pry::WrappedModule(target_self) if target_self.is_a?(Module)
+
+      Pry::WrappedModule(target_self.class)
     end
 
     def class_code
