@@ -1,6 +1,5 @@
 class Pry
   class Editor
-    include Pry::Helpers::BaseHelpers
     include Pry::Helpers::CommandHelpers
 
     attr_reader :_pry_
@@ -9,7 +8,7 @@ class Pry
       @_pry_ = _pry_
     end
 
-    def edit_tempfile_with_content(initial_content, line=1)
+    def edit_tempfile_with_content(initial_content, line = 1)
       temp_file do |f|
         f.puts(initial_content)
         f.flush
@@ -19,13 +18,13 @@ class Pry
       end
     end
 
-    def invoke_editor(file, line, blocking=true)
+    def invoke_editor(file, line, blocking = true)
       raise CommandError, "Please set Pry.config.editor or export $VISUAL or $EDITOR" unless _pry_.config.editor
 
       editor_invocation = build_editor_invocation_string(file, line, blocking)
       return nil unless editor_invocation
 
-      if jruby?
+      if Helpers::Platform.jruby?
         open_editor_on_jruby(editor_invocation)
       else
         open_editor(editor_invocation)
@@ -43,12 +42,7 @@ class Pry
         args = [file, line, blocking][0...(_pry_.config.editor.arity)]
         _pry_.config.editor.call(*args)
       else
-        sanitized_file = if windows?
-                            file
-                          else
-                            Shellwords.escape(file)
-                          end
-
+        sanitized_file = Helpers::Platform.windows? ? file : Shellwords.escape(file)
         "#{_pry_.config.editor} #{blocking_flag_for_editor(blocking)} #{start_line_syntax_for_editor(sanitized_file, line)}"
       end
     end
@@ -109,7 +103,7 @@ class Pry
       when /^redcar/
         "-l#{line_number} #{file_name}"
       else
-        if windows?
+        if Helpers::Platform.windows?
           "#{file_name}"
         else
           "+#{line_number} #{file_name}"
@@ -130,6 +124,5 @@ class Pry
     def editor_name
       File.basename(_pry_.config.editor).split(" ").first
     end
-
   end
 end
