@@ -7,7 +7,7 @@ class Pry
     # @return [Fixnum] Number of lines in history when Pry first loaded.
     attr_reader :original_lines
 
-    def initialize(options={})
+    def initialize(options = {})
       @history = []
       @original_lines = 0
       @file_path = options[:file_path]
@@ -25,8 +25,8 @@ class Pry
         @pusher  = method(:push_to_readline)
         @clearer = method(:clear_readline)
       else
-        @pusher  = proc { }
-        @clearer = proc { }
+        @pusher  = proc {}
+        @clearer = proc {}
       end
     end
 
@@ -34,6 +34,8 @@ class Pry
     # @return [Integer] The number of lines loaded
     def load
       @loader.call do |line|
+        next if invalid_readline_line?(line)
+
         @pusher.call(line.chomp)
         @history << line.chomp
         @original_lines += 1
@@ -44,7 +46,9 @@ class Pry
     # @param [String] line
     # @return [String] The same line that was passed in
     def push(line)
-      unless line.empty? || (@history.last && line == @history.last)
+      empty_or_invalid_line = line.empty? || invalid_readline_line?(line)
+
+      unless empty_or_invalid_line || (@history.last && line == @history.last)
         @pusher.call(line)
         @history << line
         if !should_ignore?(line) && Pry.config.history.should_save
@@ -107,8 +111,8 @@ class Pry
       if File.exist?(path)
         File.foreach(path) { |line| yield(line) }
       end
-    rescue => error
-      warn "History file not loaded: #{error.message}"
+    rescue SystemCallError => error
+      warn "Unable to read history file: #{error.message}"
     end
 
     # The default pusher. Appends the given line to Readline::HISTORY.
@@ -132,17 +136,26 @@ class Pry
       if defined?(@history_file)
         @history_file
       else
+        unless File.exist?(history_file_path)
+          FileUtils.mkdir_p(File.dirname(history_file_path))
+        end
         @history_file = File.open(history_file_path, 'a', 0600).tap do |file|
           file.sync = true
         end
       end
-    rescue Errno::EACCES
-      warn 'History not saved; unable to open your history file for writing.'
+    rescue SystemCallError => error
+      warn "Unable to write history file: #{error.message}"
       @history_file = false
     end
 
     def history_file_path
       File.expand_path(@file_path || Pry.config.history.file)
     end
+
+    def invalid_readline_line?(line)
+      # `Readline::HISTORY << line` raises an `ArgumentError` if `line`
+      # includes a null byte
+      line.include?("\0")
+    end
   end
 end
