@@ -15,7 +15,7 @@ class Pry
     end
 
     # Ensure that duplicates have their @hooks object.
-    def initialize_copy(orig)
+    def initialize_copy(_orig)
       hooks_dup = @hooks.dup
       @hooks.each do |k, v|
         hooks_dup[k] = v.dup
@@ -32,7 +32,7 @@ class Pry
     #
     # @param [Pry::Hooks] other The `Pry::Hooks` instance to merge
     # @return [Pry:Hooks] The receiver.
-    # @see {#merge}
+    # @see #merge
     def merge!(other)
       @hooks.merge!(other.dup.hooks) do |key, array, other_array|
         temp_hash, output = {}, []
@@ -65,7 +65,7 @@ class Pry
     # @param [#call] callable The callable.
     # @yield The block to use as the callable (if no `callable` provided).
     # @return [Pry:Hooks] The receiver.
-    def add_hook(event_name, hook_name, callable=nil, &block)
+    def add_hook(event_name, hook_name, callable = nil, &block)
       event_name = event_name.to_s
 
       # do not allow duplicates, but allow multiple `nil` hooks
