@@ -39,7 +39,7 @@ class Pry
       #   contain any context.
       # @return [Pry::Method, nil] A `Pry::Method` instance containing the requested
       #   method, or `nil` if name is `nil` or no method could be located matching the parameters.
-      def from_str(name, target=TOPLEVEL_BINDING, options={})
+      def from_str(name, target = TOPLEVEL_BINDING, options = {})
         if name.nil?
           nil
         elsif name.to_s =~ /(.+)\#(\S+)\Z/
@@ -56,8 +56,8 @@ class Pry
         elsif options[:methods]
           from_obj(target.eval("self"), name, target)
         else
-          from_str(name, target, :instance => true) or
-            from_str(name, target, :methods => true)
+          from_str(name, target, instance: true) or
+            from_str(name, target, methods: true)
         end
 
       rescue Pry::RescuableException
@@ -101,7 +101,7 @@ class Pry
       # @param [Symbol] method_type The type of method: :method or :instance_method
       # @param [Binding] target The binding where the method is looked up.
       # @return [Method, UnboundMethod] The 'refined' method object.
-      def lookup_method_via_binding(obj, method_name, method_type, target=TOPLEVEL_BINDING)
+      def lookup_method_via_binding(obj, method_name, method_type, target = TOPLEVEL_BINDING)
         Pry.current[:obj] = obj
         Pry.current[:name] = method_name
         receiver = obj.is_a?(Module) ? "Module" : "Kernel"
@@ -118,7 +118,7 @@ class Pry
       # @param [String] name
       # @param [Binding] target The binding where the method is looked up.
       # @return [Pry::Method, nil]
-      def from_class(klass, name, target=TOPLEVEL_BINDING)
+      def from_class(klass, name, target = TOPLEVEL_BINDING)
         new(lookup_method_via_binding(klass, name, :instance_method, target)) rescue nil
       end
       alias from_module from_class
@@ -131,7 +131,7 @@ class Pry
       # @param [String] name
       # @param [Binding] target The binding where the method is looked up.
       # @return [Pry::Method, nil]
-      def from_obj(obj, name, target=TOPLEVEL_BINDING)
+      def from_obj(obj, name, target = TOPLEVEL_BINDING)
         new(lookup_method_via_binding(obj, name, :method, target)) rescue nil
       end
 
@@ -139,12 +139,12 @@ class Pry
       # @param [Class,Module] klass
       # @param [Boolean] include_super Whether to include methods from ancestors.
       # @return [Array[Pry::Method]]
-      def all_from_class(klass, include_super=true)
-        %w(public protected private).map do |visibility|
+      def all_from_class(klass, include_super = true)
+        %w(public protected private).flat_map do |visibility|
           safe_send(klass, :"#{visibility}_instance_methods", include_super).map do |method_name|
-            new(safe_send(klass, :instance_method, method_name), :visibility => visibility.to_sym)
+            new(safe_send(klass, :instance_method, method_name), visibility: visibility.to_sym)
           end
-        end.flatten(1)
+        end
       end
 
       #
@@ -157,16 +157,16 @@ class Pry
       #
       # @return [Array[Pry::Method]]
       #
-      def all_from_obj(obj, include_super=true)
+      def all_from_obj(obj, include_super = true)
         all_from_class(singleton_class_of(obj), include_super)
       end
 
       #
       # @deprecated
-      #  please use {#all_from_obj} instead.
+      #  please use {all_from_obj} instead.
       #  the `method_type` argument is ignored.
       #
-      def all_from_common(obj, method_type = nil, include_super=true)
+      def all_from_common(obj, _method_type = nil, include_super = true)
         all_from_obj(obj, include_super)
       end
 
@@ -212,9 +212,9 @@ class Pry
       # the lowest copy will be returned.
       def singleton_class_resolution_order(klass)
         ancestors = Pry::Method.safe_send(klass, :ancestors)
-        resolution_order = ancestors.grep(Class).map do |anc|
+        resolution_order = ancestors.grep(Class).flat_map do |anc|
           [singleton_class_of(anc), *singleton_class_of(anc).included_modules]
-        end.flatten(1)
+        end
 
         resolution_order.reverse.uniq.reverse - Class.included_modules
       end
@@ -233,7 +233,7 @@ class Pry
     # @param [::Method, UnboundMethod, Proc] method
     # @param [Hash] known_info Can be used to pre-cache expensive to compute stuff.
     # @return [Pry::Method]
-    def initialize(method, known_info={})
+    def initialize(method, known_info = {})
       @method = method
       @visibility = known_info[:visibility]
     end
@@ -298,7 +298,8 @@ class Pry
     # @return [String, nil] The documentation for the method, or `nil` if it's
     #   unavailable.
     def doc
-      @doc ||= case source_type
+      @doc ||=
+        case source_type
         when :c
           info = pry_doc_info
           info.docstring if info
@@ -317,7 +318,7 @@ class Pry
     #   `nil` if the filename is unavailable.
     def source_file
       if source_location.nil?
-        if !rbx? and source_type == :c
+        if source_type == :c
           info = pry_doc_info
           info.file if info
         end
@@ -354,20 +355,24 @@ class Pry
 
     # @return [String] A representation of the method's signature, including its
     #   name and parameters. Optional and "rest" parameters are marked with `*`
-    #   and block parameters with `&`. If the parameter names are unavailable,
-    #   they're given numbered names instead.
+    #   and block parameters with `&`. Keyword arguments are shown with `:`
+    #   If the parameter names are unavailable, they're given numbered names instead.
     #   Paraphrased from `awesome_print` gem.
     def signature
       if respond_to?(:parameters)
-        args = parameters.inject([]) do |arr, (type, name)|
-          name ||= (type == :block ? 'block' : "arg#{arr.size + 1}")
-          arr << case type
-                 when :req   then name.to_s
-                 when :opt   then "#{name}=?"
-                 when :rest  then "*#{name}"
-                 when :block then "&#{name}"
-                 else '?'
-                 end
+        args = parameters.inject([]) do |args_array, (arg_type, name)|
+          name ||= (arg_type == :block ? 'block' : "arg#{args_array.size + 1}")
+          args_array.push(
+            case arg_type
+            when :req    then name.to_s
+            when :opt    then "#{name}=?"
+            when :rest   then "*#{name}"
+            when :block  then "&#{name}"
+            when :key    then "#{name}:?"
+            when :keyreq then "#{name}:"
+            else '?'
+            end
+          )
         end
       else
         args = (1..arity.abs).map { |i| "arg#{i}" }
@@ -379,7 +384,7 @@ class Pry
 
     # @return [Pry::Method, nil] The wrapped method that is called when you
     #   use "super" in the body of this method.
-    def super(times=1)
+    def super(times = 1)
       if UnboundMethod === @method
         sup = super_using_ancestors(Pry::Method.instance_resolution_order(owner), times)
       else
@@ -393,6 +398,7 @@ class Pry
     #   before any aliasing, or `nil` if it can't be determined.
     def original_name
       return nil if source_type != :ruby
+
       method_name_from_first_line(source.lines.first)
     end
 
@@ -461,8 +467,8 @@ class Pry
 
     # @param [String, Symbol] method_name
     # @return [Boolean]
-    def respond_to?(method_name)
-      super or @method.respond_to?(method_name)
+    def respond_to?(method_name, include_all = false)
+      super or @method.respond_to?(method_name, include_all)
     end
 
     # Delegate any unknown calls to the wrapped method.
@@ -483,8 +489,8 @@ class Pry
         Pry::MethodInfo.info_for(@method) or raise CommandError, "Cannot locate this method: #{name}. (source_location returns nil)"
       else
         fail_msg = "Cannot locate this method: #{name}."
-        if mri?
-          fail_msg += ' Try `gem-install pry-doc` to get access to Ruby Core documentation.'
+        if Helpers::Platform.mri?
+          fail_msg += " Invoke the 'gem-install pry-doc' Pry command to get access to Ruby Core documentation.\n"
         end
         raise CommandError, fail_msg
       end
@@ -492,7 +498,7 @@ class Pry
 
     # @param [Class, Module] ancestors The ancestors to investigate
     # @return [Method] The unwrapped super-method
-    def super_using_ancestors(ancestors, times=1)
+    def super_using_ancestors(ancestors, times = 1)
       next_owner = self.owner
       times.times do
         i = ancestors.index(next_owner) + 1
@@ -529,9 +535,9 @@ class Pry
     end
 
     def ruby_source
-      # clone of MethodSource.source_helper that knows to use our
-      # hacked version of source_location for rbx core methods, and
-      # our input buffer for methods defined in (pry)
+      # Clone of `MethodSource.source_helper` that knows to use our
+      # hacked version of `source_location` for our input buffer for methods
+      # defined in `(pry)`.
       file, line = *source_location
       raise SourceNotFoundError, "Could not locate source for #{name_with_owner}!" unless file
 
