@@ -8,8 +8,9 @@ class Pry::Output
 
   def puts(*objs)
     return print "\n" if objs.empty?
+
     objs.each do |obj|
-      if ary = Array.try_convert(obj)
+      if (ary = Array.try_convert(obj))
         puts(*ary)
       else
         print "#{obj.to_s.chomp}\n"
@@ -35,7 +36,7 @@ class Pry::Output
     @boxed_io.__send__(name, *args, &block)
   end
 
-  def respond_to_missing?(m, include_all=false)
+  def respond_to_missing?(m, include_all = false)
     @boxed_io.respond_to?(m, include_all)
   end
 
