@@ -1,4 +1,4 @@
-require 'pry/module_candidate'
+require 'pry/wrapped_module/candidate'
 
 class Pry
   class << self
@@ -26,7 +26,7 @@ class Pry
     # @return [Module, nil] The module or `nil` (if conversion failed).
     # @example
     #   Pry::WrappedModule.from_str("Pry::Code")
-    def self.from_str(mod_name, target=TOPLEVEL_BINDING)
+    def self.from_str(mod_name, target = TOPLEVEL_BINDING)
       if safe_to_evaluate?(mod_name, target)
         Pry::WrappedModule.new(target.eval(mod_name))
       else
@@ -48,6 +48,8 @@ class Pry
       # @return [Boolean]
       def safe_to_evaluate?(str, target)
         return true if str.strip == "self"
+        return false if str =~ /%/
+
         kind = target.eval("defined?(#{str})")
         kind =~ /variable|constant/
       end
@@ -57,36 +59,23 @@ class Pry
     # @param [Module] mod
     def initialize(mod)
       raise ArgumentError, "Tried to initialize a WrappedModule with a non-module #{mod.inspect}" unless ::Module === mod
+
       @wrapped = mod
       @memoized_candidates = []
       @host_file_lines = nil
       @source = nil
       @source_location = nil
       @doc = nil
+      @all_source_locations_by_popularity = nil
     end
 
     # Returns an array of the names of the constants accessible in the wrapped
-    # module. This provides a consistent interface between 1.8 and 1.9 and also
-    # avoids the problem of accidentally calling the singleton method
-    # `Module.constants`.
-    # @param [Boolean] inherit (true) Include the names of constants from
-    #   included modules?
+    # module. This avoids the problem of accidentally calling the singleton
+    # method `Module.constants`.
+    # @param [Boolean] inherit Include the names of constants from included
+    #   modules?
     def constants(inherit = true)
-      method = Module.instance_method(:constants).bind(@wrapped)
-
-      # If we're on 1.8, we have to manually remove ancestors' constants. If
-      # we're on 1.9, though, it's better to use the built-in `inherit` param,
-      # since it doesn't do things like incorrectly remove Pry::Config.
-      if method.arity == 0
-        consts = method.call
-        if !inherit
-          consts -= (@wrapped.ancestors - [@wrapped]).map(&:constants).flatten
-        end
-      else
-        consts = method.call(inherit)
-      end
-
-      consts
+      Module.instance_method(:constants).bind(@wrapped).call(inherit)
     end
 
     # The prefix that would appear before methods defined on this class.
@@ -120,10 +109,10 @@ class Pry
     # Is this a singleton class?
     # @return [Boolean]
     def singleton_class?
-      if wrapped.respond_to?(:singleton_class?)
-        wrapped.singleton_class?
+      if Pry::Method.safe_send(wrapped, :respond_to?, :singleton_class?)
+        Pry::Method.safe_send(wrapped, :singleton_class?)
       else
-        wrapped != wrapped.ancestors.first
+        wrapped != Pry::Method.safe_send(wrapped, :ancestors).first
       end
     end
 
@@ -147,10 +136,10 @@ class Pry
     def singleton_instance
       raise ArgumentError, "tried to get instance of non singleton class" unless singleton_class?
 
-      if Helpers::BaseHelpers.jruby?
+      if Helpers::Platform.jruby?
         wrapped.to_java.attached
       else
-        @singleton_instance ||= ObjectSpace.each_object(wrapped).detect{ |x| (class << x; self; end) == wrapped }
+        @singleton_instance ||= ObjectSpace.each_object(wrapped).detect { |x| (class << x; self; end) == wrapped }
       end
     end
 
@@ -159,15 +148,14 @@ class Pry
       wrapped.send(method_name, *args, &block)
     end
 
-    def respond_to?(method_name)
-      super || wrapped.respond_to?(method_name)
+    def respond_to?(method_name, include_all = false)
+      super || wrapped.respond_to?(method_name, include_all)
     end
 
     # Retrieve the source location of a module. Return value is in same
     # format as Method#source_location. If the source location
     # cannot be found this method returns `nil`.
     #
-    # @param [Module] mod The module (or class).
     # @return [Array<String, Fixnum>, nil] The source location of the
     #   module (or class), or `nil` if no source location found.
     def source_location
@@ -242,7 +230,7 @@ class Pry
     # @param [Fixnum] rank
     # @return [Pry::WrappedModule::Candidate]
     def candidate(rank)
-      @memoized_candidates[rank] ||= Candidate.new(self, rank)
+      @memoized_candidates[rank] ||= WrappedModule::Candidate.new(self, rank)
     end
 
     # @return [Fixnum] The number of candidate definitions for the
@@ -258,12 +246,12 @@ class Pry
     # @return [Enumerator, Array] on JRuby 1.9 and higher returns Array, on
     #  other rubies returns Enumerator
     def candidates
-      enum = generator.new do |y|
+      enum = Enumerator.new do |y|
                (0...number_of_candidates).each do |num|
                  y.yield candidate(num)
                end
              end
-      Pry::Helpers::BaseHelpers.jruby_19? ? enum.to_a : enum
+      Helpers::Platform.jruby_19? ? enum.to_a : enum
     end
 
     # @return [Boolean] Whether YARD docs are available for this module.
@@ -277,7 +265,7 @@ class Pry
     #   When `self` is a `Module` then return the
     #   nth ancestor, otherwise (in the case of classes) return the
     #   nth ancestor that is a class.
-    def super(times=1)
+    def super(times = 1)
       return self if times.zero?
 
       if wrapped.is_a?(Class)
@@ -291,24 +279,17 @@ class Pry
 
     private
 
-    # Ruby 1.8 doesn't support `Enumerator` (it's called Generator instead)
-    #
-    # @return [Object] Return the appropriate generator class.
-    def generator
-      @generator ||= if defined?(Enumerator)
-                       Enumerator
-                     else
-                       require 'generator'
-                       Generator
-                     end
-    end
-
-    # @return [Pry::WrappedModule::Candidate] The candidate of rank 0,
-    #   that is the 'monkey patch' of this module with the highest
-    #   number of methods. It is considered the 'canonical' definition
-    #   for the module.
+    # @return [Pry::WrappedModule::Candidate] The candidate with the
+    #   highest rank, that is the 'monkey patch' of this module with the
+    #   highest number of methods, which contains a source code line that
+    #   defines the module. It is considered the 'canonical' definition
+    #   for the module. In the absense of a suitable candidate, the
+    #   candidate of rank 0 will be returned, or a CommandError raised if
+    #   there are no candidates at all.
     def primary_candidate
-      @primary_candidate ||= candidate(0)
+      @primary_candidate ||= candidates.find { |c| c.file } ||
+        # This will raise an exception if there is no candidate at all.
+        candidate(0)
     end
 
     # @return [Array<Array<Pry::Method>>] The array of `Pry::Method` objects,
@@ -319,7 +300,7 @@ class Pry
     #   speed up source code extraction.
     def method_candidates
       @method_candidates ||= all_source_locations_by_popularity.map do |group|
-        methods_sorted_by_source_line  = group.last.sort_by(&:source_line)
+        methods_sorted_by_source_line = group.last.sort_by(&:source_line)
         [methods_sorted_by_source_line.first, methods_sorted_by_source_line.last]
       end
     end
@@ -330,38 +311,48 @@ class Pry
 
       ims = all_relevant_methods_for(wrapped)
       @all_source_locations_by_popularity = ims.group_by { |v| Array(v.source_location).first }.
-        sort_by { |k, v| -v.size }
+        sort_by do |path, methods|
+          expanded = File.expand_path(path)
+          load_order = $LOADED_FEATURES.index { |file| expanded.end_with?(file) }
+
+          [-methods.size, load_order || (1.0 / 0.0)]
+        end
     end
 
     # We only want methods that have a non-nil `source_location`. We also
     # skip some spooky internal methods.
-    # (i.e we skip `__class_init__` because it's an odd rbx specific thing that causes tests to fail.)
+    #
     # @return [Array<Pry::Method>]
     def all_relevant_methods_for(mod)
-      all_methods_for(mod).select(&:source_location).
-        reject{ |x| x.name == '__class_init__' || method_defined_by_forwardable_module?(x) }
+      methods = all_methods_for(mod).select(&:source_location).
+        reject { |x| method_defined_by_forwardable_module?(x) }
+
+      return methods unless methods.empty?
+
+      safe_send(mod, :constants).flat_map do |const_name|
+        if (const = nested_module?(mod, const_name))
+          all_relevant_methods_for(const)
+        else
+          []
+        end
+      end
     end
 
     # Return all methods (instance methods and class methods) for a
     # given module.
     # @return [Array<Pry::Method>]
     def all_methods_for(mod)
-      all_from_common(mod, :instance_method) + all_from_common(mod, :method)
+      Pry::Method.all_from_obj(mod, false) + Pry::Method.all_from_class(mod, false)
     end
 
-    # FIXME: a variant of this method is also found in Pry::Method
-    def all_from_common(mod, method_type)
-      %w(public protected private).map do |visibility|
-        safe_send(mod, :"#{visibility}_#{method_type}s", false).select do |method_name|
-          if method_type == :method
-            safe_send(mod, method_type, method_name).owner == class << mod; self; end
-          else
-            safe_send(mod, method_type, method_name).owner == mod
-          end
-        end.map do |method_name|
-          Pry::Method.new(safe_send(mod, method_type, method_name), :visibility => visibility.to_sym)
-        end
-      end.flatten
+    def nested_module?(parent, name)
+      return if safe_send(parent, :autoload?, name)
+
+      child = safe_send(parent, :const_get, name)
+      return unless Module === child
+      return unless safe_send(child, :name) == "#{safe_send(parent, :name)}::#{name}"
+
+      child
     end
 
     # Detect methods that are defined with `def_delegator` from the Forwardable
