@@ -7,9 +7,9 @@ describe Pry::CommandSet do
     end
 
     @ctx = {
-      :target => binding,
-      :command_set => @set,
-      :pry_instance => Pry.new(output: StringIO.new)
+      target: binding,
+      command_set: @set,
+      pry_instance: Pry.new(output: StringIO.new)
     }
   end
 
@@ -77,7 +77,7 @@ describe Pry::CommandSet do
   end
 
   it 'should be able to remove its own commands, by listing name' do
-    @set.command(/^foo1/, 'desc', :listing => 'foo') {}
+    @set.command(/^foo1/, 'desc', listing: 'foo') {}
     @set.delete 'foo'
 
     expect { @set.run_command @ctx, /^foo1/ }.to raise_error Pry::NoCommandError
@@ -125,7 +125,7 @@ describe Pry::CommandSet do
     run = false
 
     other_set = Pry::CommandSet.new do
-      command(/^foo1/, 'desc', :listing => 'foo') { run = true }
+      command(/^foo1/, 'desc', listing: 'foo') { run = true }
     end
 
     @set.import_from(other_set, 'foo')
@@ -195,14 +195,14 @@ describe Pry::CommandSet do
 
     it 'should inherit options from original command' do
       run = false
-      @set.command('foo', 'stuff', :shellwords => true, :interpolate => false) { run = true }
+      @set.command('foo', 'stuff', shellwords: true, interpolate: false) { run = true }
 
       @set.alias_command 'bar', 'foo'
       expect(@set['bar'].options[:shellwords]).to eq @set['foo'].options[:shellwords]
       expect(@set['bar'].options[:interpolate]).to eq @set['foo'].options[:interpolate]
 
       # however some options should not be inherited
-      expect(@set['bar'].options[:listing]).not_to eq  @set['foo'].options[:listing]
+      expect(@set['bar'].options[:listing]).not_to eq @set['foo'].options[:listing]
       expect(@set['bar'].options[:listing]).to eq "bar"
     end
 
@@ -210,7 +210,7 @@ describe Pry::CommandSet do
       run = false
       @set.command('foo', 'stuff') { run = true }
 
-      @set.alias_command 'bar', 'foo', :desc => "tobina"
+      @set.alias_command 'bar', 'foo', desc: "tobina"
       expect(@set['bar'].match).to eq 'bar'
       expect(@set['bar'].description).to eq "tobina"
 
@@ -220,7 +220,7 @@ describe Pry::CommandSet do
 
     it "should be able to alias a command by its invocation line" do
       run = false
-      @set.command(/^foo1/, 'stuff', :listing => 'foo') { run = true }
+      @set.command(/^foo1/, 'stuff', listing: 'foo') { run = true }
 
       @set.alias_command 'bar', 'foo1'
       expect(@set['bar'].match).to eq 'bar'
@@ -232,15 +232,15 @@ describe Pry::CommandSet do
 
     it "should be able to specify options when creating alias" do
       run = false
-      @set.command(/^foo1/, 'stuff', :listing => 'foo') { run = true }
+      @set.command(/^foo1/, 'stuff', listing: 'foo') { run = true }
 
-      @set.alias_command(/^b.r/, 'foo1', :listing => "bar")
+      @set.alias_command(/^b.r/, 'foo1', listing: "bar")
       expect(@set.to_hash[/^b.r/].options[:listing]).to eq "bar"
     end
 
     it "should set description to default if description parameter is nil" do
       run = false
-      @set.command(/^foo1/, 'stuff', :listing => 'foo') { run = true }
+      @set.command(/^foo1/, 'stuff', listing: 'foo') { run = true }
 
       @set.alias_command "bar", 'foo1'
       expect(@set["bar"].description).to eq "Alias for `foo1`"
@@ -260,7 +260,7 @@ describe Pry::CommandSet do
   end
 
   it 'should get the descriptions of commands, by listing' do
-    @set.command(/^foo1/, 'bar', :listing => 'foo') {}
+    @set.command(/^foo1/, 'bar', listing: 'foo') {}
     expect(@set.desc('foo')).to eq 'bar'
   end
 
@@ -270,12 +270,12 @@ describe Pry::CommandSet do
   end
 
   it 'should be able to keep return values' do
-    @set.command('foo', '', :keep_retval => true) { 3 }
+    @set.command('foo', '', keep_retval: true) { 3 }
     expect(@set.run_command(@ctx, 'foo')).to eq 3
   end
 
   it 'should be able to keep return values, even if return value is nil' do
-    @set.command('foo', '', :keep_retval => true) { nil }
+    @set.command('foo', '', keep_retval: true) { nil }
     expect(@set.run_command(@ctx, 'foo')).to eq nil
   end
 
@@ -285,7 +285,7 @@ describe Pry::CommandSet do
 
     @set.run_command(@ctx, 'foo')
     expect(Pry::Command.subclass('foo', '', {}, Module.new)
-                .new({:target => binding}))
+                .new({target: binding}))
                 .not_to(respond_to :my_helper)
   end
 
@@ -338,7 +338,7 @@ describe Pry::CommandSet do
   end
 
   it 'should provide a :listing for a command that differs from its name' do
-    @set.command 'foo', "", :listing => 'bar' do;end
+    @set.command 'foo', "", listing: 'bar' do;end
     expect(@set['foo'].options[:listing]).to eq 'bar'
   end
 
@@ -349,7 +349,6 @@ describe Pry::CommandSet do
     expect { @set.run_command(@ctx, 'help') }.to_not raise_error
   end
 
-
   describe "renaming a command" do
     it 'should be able to rename and run a command' do
       run = false
@@ -361,7 +360,7 @@ describe Pry::CommandSet do
 
     it 'should accept listing name when renaming a command' do
       run = false
-      @set.command('foo', "", :listing => 'love') { run = true }
+      @set.command('foo', "", listing: 'love') { run = true }
       @set.rename_command('bar', 'love')
       @set.run_command(@ctx, 'bar')
       expect(run).to eq true
@@ -372,7 +371,7 @@ describe Pry::CommandSet do
     end
 
     it 'should make old command name inaccessible' do
-      @set.command('foo') { }
+      @set.command('foo') {}
       @set.rename_command('bar', 'foo')
       expect { @set.run_command(@ctx, 'foo') }.to raise_error Pry::NoCommandError
     end
@@ -380,163 +379,160 @@ describe Pry::CommandSet do
     it 'should be able to pass in options when renaming command' do
       desc    = "hello"
       listing = "bing"
-      @set.command('foo') { }
-      @set.rename_command('bar', 'foo', :description => desc, :listing => listing, :keep_retval => true)
+      @set.command('foo') {}
+      @set.rename_command('bar', 'foo', description: desc, listing: listing, keep_retval: true)
       expect(@set['bar'].description).to           eq desc
       expect(@set['bar'].options[:listing]).to     eq listing
       expect(@set['bar'].options[:keep_retval]).to eq true
     end
   end
 
-  describe "command decorators - before_command and after_command" do
-    describe "before_command" do
-      it 'should be called before the original command' do
-        foo = []
-        @set.command('foo') { foo << 1 }
-        @set.before_command('foo') { foo << 2 }
-        @set.run_command(@ctx, 'foo')
-
-        expect(foo).to eq [2, 1]
-      end
-
-      it 'should be called before the original command, using listing name' do
-        foo = []
-        @set.command(/^foo1/, '', :listing => 'foo') { foo << 1 }
-        @set.before_command('foo') { foo << 2 }
-        @set.run_command(@ctx, /^foo1/)
-
-        expect(foo).to eq [2, 1]
-      end
-
-      it 'should share the context with the original command' do
-        @ctx[:target] = "test target string".__binding__
-        before_val  = nil
-        orig_val    = nil
-        @set.command('foo') { orig_val = target }
-        @set.before_command('foo') { before_val = target }
-        @set.run_command(@ctx, 'foo')
-
-        expect(before_val).to eq @ctx[:target]
-        expect(orig_val).to eq @ctx[:target]
-      end
-
-      it 'should work when applied multiple times' do
-        foo = []
-        @set.command('foo') { foo << 1 }
-        @set.before_command('foo') { foo << 2 }
-        @set.before_command('foo') { foo << 3 }
-        @set.before_command('foo') { foo << 4 }
-        @set.run_command(@ctx, 'foo')
-
-        expect(foo).to eq [2, 3, 4, 1]
-      end
+  describe "before_* hook" do
+    it 'should be called before the original command' do
+      foo = []
+      @set.command('foo') { foo << 1 }
+      @set['foo'].hooks.add_hook('before_foo', 'name') { foo << 2 }
+      @set.run_command(@ctx, 'foo')
 
+      expect(foo).to eq [2, 1]
     end
 
-    describe "after_command" do
-      it 'should be called after the original command' do
-        foo = []
-        @set.command('foo') { foo << 1 }
-        @set.after_command('foo') { foo << 2 }
-        @set.run_command(@ctx, 'foo')
+    it 'should be called before the original command, using listing name' do
+      foo = []
+      @set.command(/^foo1/, '', listing: 'foo') { foo << 1 }
+      cmd = @set.find_command_by_match_or_listing('foo')
+      cmd.hooks.add_hook('before_foo', 'name') { foo << 2 }
+      @set.run_command(@ctx, /^foo1/)
 
-        expect(foo).to eq [1, 2]
-      end
-
-      it 'should be called after the original command, using listing name' do
-        foo = []
-        @set.command(/^foo1/, '', :listing => 'foo') { foo << 1 }
-        @set.after_command('foo') { foo << 2 }
-        @set.run_command(@ctx, /^foo1/)
-
-        expect(foo).to eq [1, 2]
-      end
-
-      it 'should share the context with the original command' do
-        @ctx[:target] = "test target string".__binding__
-        after_val   = nil
-        orig_val    = nil
-        @set.command('foo') { orig_val = target }
-        @set.after_command('foo') { after_val = target }
-        @set.run_command(@ctx, 'foo')
-
-        expect(after_val).to eq @ctx[:target]
-        expect(orig_val).to eq @ctx[:target]
-      end
-
-      it 'should determine the return value for the command' do
-        @set.command('foo', 'bar', :keep_retval => true) { 1 }
-        @set.after_command('foo') { 2 }
-        expect(@set.run_command(@ctx, 'foo')).to eq 2
-      end
-
-      it 'should work when applied multiple times' do
-        foo = []
-        @set.command('foo') { foo << 1 }
-        @set.after_command('foo') { foo << 2 }
-        @set.after_command('foo') { foo << 3 }
-        @set.after_command('foo') { foo << 4 }
-        @set.run_command(@ctx, 'foo')
-
-        expect(foo).to eq [1, 2, 3, 4]
-      end
+      expect(foo).to eq [2, 1]
     end
 
-    describe "before_command and after_command" do
-      it 'should work when combining both before_command and after_command' do
-        foo = []
-        @set.command('foo') { foo << 1 }
-        @set.after_command('foo') { foo << 2 }
-        @set.before_command('foo') { foo << 3 }
-        @set.run_command(@ctx, 'foo')
-
-        expect(foo).to eq [3, 1, 2]
-      end
+    it 'should share the context with the original command' do
+      @ctx[:target] = "test target string".__binding__
+      before_val  = nil
+      orig_val    = nil
+      @set.command('foo') { orig_val = target }
+      @set['foo'].hooks.add_hook('before_foo', 'name') { before_val = target }
+      @set.run_command(@ctx, 'foo')
 
+      expect(before_val).to eq @ctx[:target]
+      expect(orig_val).to eq @ctx[:target]
     end
 
+    it 'should work when applied multiple times' do
+      foo = []
+      @set.command('foo') { foo << 1 }
+      @set['foo'].hooks.add_hook('before_foo', 'name1') { foo << 2 }
+      @set['foo'].hooks.add_hook('before_foo', 'name2') { foo << 3 }
+      @set['foo'].hooks.add_hook('before_foo', 'name3') { foo << 4 }
+      @set.run_command(@ctx, 'foo')
+
+      expect(foo).to eq [2, 3, 4, 1]
+    end
+  end
+
+  describe "after_* hooks" do
+    it 'should be called after the original command' do
+      foo = []
+      @set.command('foo') { foo << 1 }
+      @set['foo'].hooks.add_hook('after_foo', 'name') { foo << 2 }
+      @set.run_command(@ctx, 'foo')
+
+      expect(foo).to eq [1, 2]
+    end
+
+    it 'should be called after the original command, using listing name' do
+      foo = []
+      @set.command(/^foo1/, '', listing: 'foo') { foo << 1 }
+      cmd = @set.find_command_by_match_or_listing('foo')
+      cmd.hooks.add_hook('after_foo', 'name') { foo << 2 }
+      @set.run_command(@ctx, /^foo1/)
+
+      expect(foo).to eq [1, 2]
+    end
+
+    it 'should share the context with the original command' do
+      @ctx[:target] = "test target string".__binding__
+      after_val   = nil
+      orig_val    = nil
+      @set.command('foo') { orig_val = target }
+      @set['foo'].hooks.add_hook('after_foo', 'name') { after_val = target }
+      @set.run_command(@ctx, 'foo')
+
+      expect(after_val).to eq @ctx[:target]
+      expect(orig_val).to eq @ctx[:target]
+    end
+
+    it 'should determine the return value for the command' do
+      @set.command('foo', 'bar', keep_retval: true) { 1 }
+      @set['foo'].hooks.add_hook('after_foo', 'name') { 2 }
+      expect(@set.run_command(@ctx, 'foo')).to eq 2
+    end
+
+    it 'should work when applied multiple times' do
+      foo = []
+      @set.command('foo') { foo << 1 }
+      @set['foo'].hooks.add_hook('after_foo', 'name1') { foo << 2 }
+      @set['foo'].hooks.add_hook('after_foo', 'name2') { foo << 3 }
+      @set['foo'].hooks.add_hook('after_foo', 'name3') { foo << 4 }
+      @set.run_command(@ctx, 'foo')
+
+      expect(foo).to eq [1, 2, 3, 4]
+    end
+  end
+
+  describe "before_command and after_command" do
+    it 'should work when combining both before_command and after_command' do
+      foo = []
+      @set.command('foo') { foo << 1 }
+      @set['foo'].hooks.add_hook('after_foo', 'name') { foo << 2 }
+      @set['foo'].hooks.add_hook('before_foo', 'name') { foo << 3 }
+      @set.run_command(@ctx, 'foo')
+
+      expect(foo).to eq [3, 1, 2]
+    end
   end
 
   describe 'find_command' do
     it 'should find commands with the right string' do
-      cmd = @set.command('rincewind'){ }
+      cmd = @set.command('rincewind') {}
       expect(@set.find_command('rincewind')).to eq cmd
     end
 
     it 'should not find commands with spaces before' do
-      @set.command('luggage'){ }
+      @set.command('luggage') {}
       expect(@set.find_command(' luggage')).to eq nil
     end
 
     it 'should find commands with arguments after' do
-      cmd = @set.command('vetinari'){ }
+      cmd = @set.command('vetinari') {}
       expect(@set.find_command('vetinari --knock 3')).to eq cmd
     end
 
     it 'should find commands with names containing spaces' do
-      cmd = @set.command('nobby nobbs'){ }
+      cmd = @set.command('nobby nobbs') {}
       expect(@set.find_command('nobby nobbs --steal petty-cash')).to eq cmd
     end
 
     it 'should find command defined by regex' do
-      cmd = @set.command(/(capt|captain) vimes/i){ }
+      cmd = @set.command(/(capt|captain) vimes/i) {}
       expect(@set.find_command('Capt Vimes')).to eq cmd
     end
 
     it 'should find commands defined by regex with arguments' do
-      cmd = @set.command(/(cpl|corporal) Carrot/i){ }
+      cmd = @set.command(/(cpl|corporal) Carrot/i) {}
       expect(@set.find_command('cpl carrot --write-home')).to eq cmd
     end
 
     it 'should not find commands by listing' do
-      @set.command(/werewol(f|ve)s?/, 'only once a month', :listing => "angua"){ }
+      @set.command(/werewol(f|ve)s?/, 'only once a month', listing: "angua") {}
       expect(@set.find_command('angua')).to eq nil
     end
 
     it 'should not find commands without command_prefix' do
       begin
         Pry.config.command_prefix = '%'
-        @set.command('detritus'){ }
+        @set.command('detritus') {}
         expect(@set.find_command('detritus')).to eq nil
       ensure
         Pry.config.command_prefix = ''
@@ -546,7 +542,7 @@ describe Pry::CommandSet do
     it "should find commands that don't use the prefix" do
       begin
         Pry.config.command_prefix = '%'
-        cmd = @set.command('colon', 'Sergeant Fred', :use_prefix => false){ }
+        cmd = @set.command('colon', 'Sergeant Fred', use_prefix: false) {}
         expect(@set.find_command('colon')).to eq cmd
       ensure
         Pry.config.command_prefix = ''
@@ -554,14 +550,14 @@ describe Pry::CommandSet do
     end
 
     it "should find the command that has the longest match" do
-      @set.command(/\.(.*)/){ }
-      cmd2 = @set.command(/\.\|\|(.*)/){ }
+      @set.command(/\.(.*)/) {}
+      cmd2 = @set.command(/\.\|\|(.*)/) {}
       expect(@set.find_command('.||')).to eq cmd2
     end
 
     it "should find the command that has the longest name" do
-      @set.command(/\.(.*)/){ }
-      cmd2 = @set.command('.||'){ }
+      @set.command(/\.(.*)/) {}
+      cmd2 = @set.command('.||') {}
       expect(@set.find_command('.||')).to eq cmd2
     end
   end
@@ -583,7 +579,6 @@ describe Pry::CommandSet do
   end
 
   describe '.process_line' do
-
     it 'should return Result.new(false) if there is no matching command' do
      result = @set.process_line('1 + 42')
      expect(result.command?).to eq false
@@ -603,7 +598,7 @@ describe Pry::CommandSet do
     end
 
     it 'should return Result.new(true, retval) if the command is keep_retval' do
-      @set.create_command('magrat', 'the maiden', :keep_retval => true) do
+      @set.create_command('magrat', 'the maiden', keep_retval: true) do
         def process; 42; end
       end
 
@@ -615,10 +610,10 @@ describe Pry::CommandSet do
 
     it 'should pass through context' do
       ctx = {
-        :eval_string => "bloomers",
-        :pry_instance => Object.new,
-        :output => StringIO.new,
-        :target => binding
+        eval_string: "bloomers",
+        pry_instance: Object.new,
+        output: StringIO.new,
+        target: binding
       }
 
       inside = inner_scope do |probe|
@@ -651,12 +646,12 @@ describe Pry::CommandSet do
   if defined?(Bond)
     describe '.complete' do
       it "should list all command names" do
-        @set.create_command('susan'){ }
+        @set.create_command('susan') {}
         expect(@set.complete('sus')).to.include 'susan '
       end
 
       it "should delegate to commands" do
-        @set.create_command('susan'){ def complete(search); ['--foo']; end }
+        @set.create_command('susan') { def complete(_search); ['--foo']; end }
         expect(@set.complete('susan ')).to eq ['--foo']
       end
     end
