@@ -20,7 +20,7 @@ describe "edit" do
       # OS-specific tempdir name. For GNU/Linux it's "tmp", for Windows it's
       # something "Temp".
       @tf_dir =
-        if Pry::Helpers::BaseHelpers.mri_19?
+        if Pry::Helpers::Platform.mri_19?
           Pathname.new(Dir::Tmpname.tmpdir)
         else
           Pathname.new(Dir.tmpdir)
@@ -75,12 +75,8 @@ describe "edit" do
     if respond_to?(:require_relative, true)
       it "should work with require relative" do
         Pry.config.editor = lambda { |file, line|
-          File.open(file, 'w'){ |f| f << 'require_relative "baz.rb"' }
-          File.open(file.gsub('bar.rb', 'baz.rb'), 'w'){ |f| f << "Pad.required = true; FileUtils.rm(__FILE__)" }
-
-          if defined?(Rubinius::Compiler)
-            File.unlink Rubinius::Compiler.compiled_name file
-          end
+          File.open(file, 'w') { |f| f << 'require_relative "baz.rb"' }
+          File.open(file.gsub('bar.rb', 'baz.rb'), 'w') { |f| f << "Pad.required = true; FileUtils.rm(__FILE__)" }
           nil
         }
         pry_eval "edit #@tf_path"
@@ -166,6 +162,7 @@ describe "edit" do
         def last_exception=(exception)
           @pry.last_exception = exception
         end
+
         def last_exception; @pry.last_exception; end
       end
     end
@@ -186,15 +183,11 @@ describe "edit" do
 
       after do
         @tf.close(true)
-        File.unlink("#{@path}c") if File.exist?("#{@path}c") #rbx
       end
 
       it "should reload the file" do
-        Pry.config.editor = lambda {|file, line|
-          File.open(file, 'w'){|f| f << "FOO = 'BAR'" }
-          if defined?(Rubinius::Compiler)
-            File.unlink Rubinius::Compiler.compiled_name file
-          end
+        Pry.config.editor = lambda { |file, line|
+          File.open(file, 'w') { |f| f << "FOO = 'BAR'" }
           nil
         }
 
@@ -209,7 +202,7 @@ describe "edit" do
       # of the exception)
       it 'edits the exception even when in a patched method context' do
         source_location = nil
-        Pry.config.editor = lambda {|file, line|
+        Pry.config.editor = lambda { |file, line|
           source_location = [file, line]
           nil
         }
@@ -227,8 +220,8 @@ describe "edit" do
       end
 
       it "should not reload the file if -n is passed" do
-        Pry.config.editor = lambda {|file, line|
-          File.open(file, 'w'){|f| f << "FOO2 = 'BAZ'" }
+        Pry.config.editor = lambda { |file, line|
+          File.open(file, 'w') { |f| f << "FOO2 = 'BAZ'" }
           nil
         }
 
@@ -242,8 +235,8 @@ describe "edit" do
       describe "with --patch" do
         # Original source code must be untouched.
         it "should apply changes only in memory (monkey patching)" do
-          Pry.config.editor = lambda {|file, line|
-            File.open(file, 'w'){|f| f << "FOO3 = 'PIYO'" }
+          Pry.config.editor = lambda { |file, line|
+            File.open(file, 'w') { |f| f << "FOO3 = 'PIYO'" }
             @patched_def = File.open(file, 'r').read
             nil
           }
@@ -339,8 +332,8 @@ describe "edit" do
     end
 
     it "should evaluate the expression" do
-      Pry.config.editor = lambda {|file, line|
-        File.open(file, 'w'){|f| f << "'FOO'\n" }
+      Pry.config.editor = lambda { |file, line|
+        File.open(file, 'w') { |f| f << "'FOO'\n" }
         nil
       }
       @t.process_command 'edit'
@@ -348,8 +341,8 @@ describe "edit" do
     end
 
     it "should ignore -n for tempfiles" do
-      Pry.config.editor = lambda {|file, line|
-        File.open(file, 'w'){|f| f << "'FOO'\n" }
+      Pry.config.editor = lambda { |file, line|
+        File.open(file, 'w') { |f| f << "'FOO'\n" }
         nil
       }
       @t.process_command "edit -n"
@@ -357,8 +350,8 @@ describe "edit" do
     end
 
     it "should not evaluate a file with -n" do
-      Pry.config.editor = lambda {|file, line|
-        File.open(file, 'w'){|f| f << "'FOO'\n" }
+      Pry.config.editor = lambda { |file, line|
+        File.open(file, 'w') { |f| f << "'FOO'\n" }
         nil
       }
       begin
@@ -369,6 +362,18 @@ describe "edit" do
         FileUtils.rm "spec/fixtures/foo.rb"
       end
     end
+
+    it "should write the evaluated command to history" do
+      quote = 'history repeats itself, first as tradegy...'
+      Pry.config.editor = lambda { |file, line|
+        File.open(file, 'w') { |f|
+          f << quote
+        }
+        nil
+      }
+      @t.process_command 'edit'
+      expect(Pry.history.to_a.last).to eq quote
+    end
   end
 
   describe "with --in" do
@@ -429,7 +434,7 @@ describe "edit" do
       expect(klass.new.m).to eq 3
 
       # original file is unchanged
-      expect(File.readlines(filename)[line-1].strip).to eq 'def m; 1; end'
+      expect(File.readlines(filename)[line - 1].strip).to eq 'def m; 1; end'
     end
 
     it 'can repeatedly edit methods that were defined in the console' do
@@ -521,7 +526,6 @@ describe "edit" do
 
           expect(@file).to eq @tempfile_path
           expect(@line).to eq 14
-
         end
 
         it "should correctly find an instance method" do
@@ -713,11 +717,9 @@ describe "edit" do
         end
 
         it "should change the alias, but not the original, without breaking super" do
-
           $x = :bebe
           pry_eval 'edit -p X#c'
 
-
           expect(Pry::Method.from_str("X#c").alias?).to eq true
 
           expect(X.new.b).to eq :kinda
@@ -783,7 +785,7 @@ describe "edit" do
       end
 
       t = pry_tester(BinkyWink.new.m1)
-      expect { t.process_command "edit -m -n" }.to  raise_error(Pry::CommandError, /Cannot find a file for/)
+      expect { t.process_command "edit -m -n" }.to raise_error(Pry::CommandError, /Cannot find a file for/)
     end
 
     it 'errors when a filename arg is passed with --method' do
