@@ -47,7 +47,7 @@ describe "show-source" do
   end
 
   it "should find methods even if there are spaces in the arguments" do
-    def @o.foo(*bars)
+    def @o.foo(*_bars)
       @foo = "Mr flibble"
       self
     end
@@ -57,7 +57,7 @@ describe "show-source" do
   end
 
   it "should find methods even if the object overrides method method" do
-    _c = Class.new{
+    _c = Class.new {
       def method;
         98
       end
@@ -67,7 +67,7 @@ describe "show-source" do
   end
 
   it "should not show the source when a non-extant method is requested" do
-    _c = Class.new{ def method; 98; end }
+    _c = Class.new { def method; 98; end }
     expect(mock_pry(binding, "show-source _c#wrongmethod")).to match(/Couldn't locate/)
   end
 
@@ -77,9 +77,8 @@ describe "show-source" do
     expect(mock_pry(binding, "show-source _c#wrongmethod")).to eq(error_message)
   end
 
-
   it "should find instance_methods if the class overrides instance_method" do
-    _c = Class.new{
+    _c = Class.new {
       def method;
         98
       end
@@ -91,37 +90,37 @@ describe "show-source" do
   end
 
   it "should find instance methods with self#moo" do
-    _c = Class.new{ def moo; "ve over!"; end }
+    _c = Class.new { def moo; "ve over!"; end }
 
     expect(pry_eval(binding, "cd _c", "show-source self#moo")).to match(/ve over/)
   end
 
   it "should not find instance methods with self.moo" do
-    _c = Class.new{ def moo; "ve over!"; end }
+    _c = Class.new { def moo; "ve over!"; end }
 
     expect { pry_eval(binding, 'cd _c', 'show-source self.moo') }.to raise_error(Pry::CommandError, /Couldn't locate/)
   end
 
   it "should find normal methods with self.moo" do
-    _c = Class.new{ def self.moo; "ve over!"; end }
+    _c = Class.new { def self.moo; "ve over!"; end }
 
     expect(pry_eval(binding, 'cd _c', 'show-source self.moo')).to match(/ve over/)
   end
 
   it "should not find normal methods with self#moo" do
-    _c = Class.new{ def self.moo; "ve over!"; end }
+    _c = Class.new { def self.moo; "ve over!"; end }
 
     expect { pry_eval(binding, 'cd _c', 'show-source self#moo') }.to raise_error(Pry::CommandError, /Couldn't locate/)
   end
 
   it "should find normal methods (i.e non-instance methods) by default" do
-    _c = Class.new{ def self.moo; "ve over!"; end }
+    _c = Class.new { def self.moo; "ve over!"; end }
 
     expect(pry_eval(binding, "cd _c", "show-source moo")).to match(/ve over/)
   end
 
   it "should find instance methods if no normal methods available" do
-    _c = Class.new{ def moo; "ve over!"; end }
+    _c = Class.new { def moo; "ve over!"; end }
 
     expect(pry_eval(binding, "cd _c", "show-source moo")).to match(/ve over/)
   end
@@ -184,10 +183,36 @@ describe "show-source" do
     Pry.config.commands.delete "hubba-hubba"
   end
 
+  context "when there's no source code but the comment exists" do
+    before do
+      class Foo
+        # Bingo.
+        def bar; end
+      end
+
+      allow_any_instance_of(Pry::Method).to receive(:source).and_return(nil)
+    end
+
+    after do
+      Object.remove_const(:Foo)
+    end
+
+    it "outputs zero line numbers" do
+      out = pry_eval('show-source Foo#bar')
+      expect(out).to match(/
+        Owner:\sFoo
+        .+
+        Number\sof\slines:\s0
+        .+
+        \*\*\sWarning:\sCannot\sfind\scode\sfor\s'bar'\s\(source_location\sis\snil\)
+      /mx)
+    end
+  end
+
   describe "finding super methods with help of `--super` switch" do
     before do
       class Foo
-        def foo(*bars)
+        def foo(*_bars)
           :super_wibble
         end
       end
@@ -198,9 +223,8 @@ describe "show-source" do
     end
 
     it "finds super methods with explicit method argument" do
-
       o = Foo.new
-      def o.foo(*bars)
+      def o.foo(*_bars)
         :wibble
       end
 
@@ -220,11 +244,13 @@ describe "show-source" do
     it "finds super methods with multiple --super " do
       o = Foo.new
 
-      o.extend Module.new {
-        def foo
-          :nibble
+      o.extend(
+        Module.new do
+          def foo
+            :nibble
+          end
         end
-      }
+      )
 
       def o.foo(*bars)
         @foo = :wibble
@@ -325,7 +351,7 @@ describe "show-source" do
           end
         end
 
-        class ShowSourceTestClass<ShowSourceTestSuperClass
+        class ShowSourceTestClass < ShowSourceTestSuperClass
           def alpha
           end
         end
@@ -428,7 +454,6 @@ describe "show-source" do
       end
 
       it 'should lookup module name with respect to current context' do
-
         temporary_constants(:AlphaClass, :BetaClass) do
           class BetaClass
             def alpha
@@ -533,6 +558,7 @@ describe "show-source" do
           module TestHost
             class M
               def alpha; end
+
               def beta; end
             end
 
@@ -595,6 +621,7 @@ describe "show-source" do
 
                 module Muesli
                   def d; end
+
                   def e; end
                 end
               end
@@ -679,7 +706,7 @@ describe "show-source" do
         end
 
         it 'should show source for a command by listing name' do
-          @set.command(/foo(.*)/, :body_of_foo_bar_regex, :listing => "bar") do; end
+          @set.command(/foo(.*)/, :body_of_foo_bar_regex, listing: "bar") do; end
 
           expect(pry_eval('show-source bar')).to match(/:body_of_foo_bar_regex/)
         end
@@ -744,116 +771,114 @@ describe "show-source" do
     end
   end
 
-  unless Pry::Helpers::BaseHelpers.rbx?
-    describe "can't find class/module code" do
-      describe "for classes" do
-        before do
-          module Jesus
-            module Pig
-              def lillybing; :lillybing; end
-            end
-
-            class Brian; end
-            class Jingle
-              def a; :doink; end
-            end
-
-            class Jangle < Jingle; include Pig; end
-            class Bangle < Jangle; end
+  describe "can't find class/module code" do
+    describe "for classes" do
+      before do
+        module Jesus
+          module Pig
+            def lillybing; :lillybing; end
           end
-        end
 
-        after do
-          Object.remove_const(:Jesus)
-        end
+          class Brian; end
+          class Jingle
+            def a; :doink; end
+          end
 
-        it 'shows superclass code' do
-          t = pry_tester
-          t.process_command "show-source Jesus::Jangle"
-          expect(t.last_output).to match(/doink/)
-        end
-
-        it 'ignores included modules' do
-          t = pry_tester
-          t.process_command "show-source Jesus::Jangle"
-          expect(t.last_output).not_to match(/lillybing/)
-        end
-
-        it 'errors when class has no superclass to show' do
-          t = pry_tester
-          expect { t.process_command "show-source Jesus::Brian" }.to raise_error(Pry::CommandError, /Couldn't locate/)
-        end
-
-        it 'shows warning when reverting to superclass code' do
-          t = pry_tester
-          t.process_command "show-source Jesus::Jangle"
-          expect(t.last_output).to match(/Warning.*?Cannot find.*?Jesus::Jangle.*Showing.*Jesus::Jingle instead/)
-        end
-
-        it 'shows nth level superclass code (when no intermediary superclasses have code either)' do
-          t = pry_tester
-          t.process_command "show-source Jesus::Bangle"
-          expect(t.last_output).to match(/doink/)
-        end
-
-        it 'shows correct warning when reverting to nth level superclass' do
-          t = pry_tester
-          t.process_command "show-source Jesus::Bangle"
-          expect(t.last_output).to match(/Warning.*?Cannot find.*?Jesus::Bangle.*Showing.*Jesus::Jingle instead/)
+          class Jangle < Jingle; include Pig; end
+          class Bangle < Jangle; end
         end
       end
 
-      describe "for modules" do
-        before do
-          module Jesus
-            module Alpha
-              def alpha; :alpha; end
-            end
+      after do
+        Object.remove_const(:Jesus)
+      end
 
-            module Zeta; end
+      it 'shows superclass code' do
+        t = pry_tester
+        t.process_command "show-source Jesus::Jangle"
+        expect(t.last_output).to match(/doink/)
+      end
 
-            module Beta
-              include Alpha
-            end
+      it 'ignores included modules' do
+        t = pry_tester
+        t.process_command "show-source Jesus::Jangle"
+        expect(t.last_output).not_to match(/lillybing/)
+      end
 
-            module Gamma
-              include Beta
-            end
+      it 'errors when class has no superclass to show' do
+        t = pry_tester
+        expect { t.process_command "show-source Jesus::Brian" }.to raise_error(Pry::CommandError, /Couldn't locate/)
+      end
+
+      it 'shows warning when reverting to superclass code' do
+        t = pry_tester
+        t.process_command "show-source Jesus::Jangle"
+        expect(t.last_output).to match(/Warning.*?Cannot find.*?Jesus::Jangle.*Showing.*Jesus::Jingle instead/)
+      end
+
+      it 'shows nth level superclass code (when no intermediary superclasses have code either)' do
+        t = pry_tester
+        t.process_command "show-source Jesus::Bangle"
+        expect(t.last_output).to match(/doink/)
+      end
+
+      it 'shows correct warning when reverting to nth level superclass' do
+        t = pry_tester
+        t.process_command "show-source Jesus::Bangle"
+        expect(t.last_output).to match(/Warning.*?Cannot find.*?Jesus::Bangle.*Showing.*Jesus::Jingle instead/)
+      end
+    end
+
+    describe "for modules" do
+      before do
+        module Jesus
+          module Alpha
+            def alpha; :alpha; end
+          end
+
+          module Zeta; end
+
+          module Beta
+            include Alpha
+          end
+
+          module Gamma
+            include Beta
           end
         end
+      end
 
-        after do
-          Object.remove_const(:Jesus)
-        end
+      after do
+        Object.remove_const(:Jesus)
+      end
 
-        it 'shows included module code' do
-          t = pry_tester
-          t.process_command "show-source Jesus::Beta"
-          expect(t.last_output).to match(/alpha/)
-        end
+      it 'shows included module code' do
+        t = pry_tester
+        t.process_command "show-source Jesus::Beta"
+        expect(t.last_output).to match(/alpha/)
+      end
 
-        it 'shows warning when reverting to included module code' do
-          t = pry_tester
-          t.process_command "show-source Jesus::Beta"
-          expect(t.last_output).to match(/Warning.*?Cannot find.*?Jesus::Beta.*Showing.*Jesus::Alpha instead/)
-        end
+      it 'shows warning when reverting to included module code' do
+        t = pry_tester
+        t.process_command "show-source Jesus::Beta"
+        expect(t.last_output).to match(/Warning.*?Cannot find.*?Jesus::Beta.*Showing.*Jesus::Alpha instead/)
+      end
 
-        it 'errors when module has no included module to show' do
-          t = pry_tester
-          expect { t.process_command "show-source Jesus::Zeta" }.to raise_error(Pry::CommandError, /Couldn't locate/)
-        end
+      it 'errors when module has no included module to show' do
+        t = pry_tester
+        expect { t.process_command "show-source Jesus::Zeta" }.to raise_error(Pry::CommandError, /Couldn't locate/)
+      end
 
-        it 'shows nth level included module code (when no intermediary modules have code either)' do
-          t = pry_tester
-          t.process_command "show-source Jesus::Gamma"
-          expect(t.last_output).to match(/alpha/)
-        end
+      it 'shows nth level included module code (when no intermediary modules have code either)' do
+        t = pry_tester
+        t.process_command "show-source Jesus::Gamma"
+        expect(t.last_output).to match(/alpha/)
+      end
 
-        it 'shows correct warning when reverting to nth level included module' do
-          t = pry_tester
-          t.process_command "show-source Jesus::Gamma"
-          expect(t.last_output).to match(/Warning.*?Cannot find.*?Jesus::Gamma.*Showing.*Jesus::Alpha instead/)
-        end
+      it 'shows correct warning when reverting to nth level included module' do
+        t = pry_tester
+        t.process_command "show-source Jesus::Gamma"
+        expect(t.last_output).to match(/Warning.*?Cannot find.*?Jesus::Gamma.*Showing.*Jesus::Alpha instead/)
       end
     end
   end
