@@ -2,13 +2,12 @@ require_relative 'helper'
 require "readline" unless defined?(Readline)
 require "pry/input_completer"
 
-def completer_test(bind, pry=nil, assert_flag=true)
-  test = proc {|symbol|
-    expect(Pry::InputCompleter.new(pry || Readline, pry).call(symbol[0..-2], :target => Pry.binding_for(bind)).include?(symbol)).to  eq(assert_flag)}
-  return proc {|*symbols| symbols.each(&test) }
+def completer_test(bind, pry = nil, assert_flag = true)
+  test = proc { |symbol|
+    expect(Pry::InputCompleter.new(pry || Readline, pry).call(symbol[0..-2], target: Pry.binding_for(bind)).include?(symbol)).to eq(assert_flag)}
+  return proc { |*symbols| symbols.each(&test) }
 end
 
-
 describe Pry::InputCompleter do
   before do
     # The AMQP gem has some classes like this:
@@ -27,15 +26,13 @@ describe Pry::InputCompleter do
     Object.remove_const :SymbolyName
   end
 
-  # another jruby hack :((
-  if !Pry::Helpers::BaseHelpers.jruby?
-    it "should not crash if there's a Module that has a symbolic name." do
-      expect { Pry::InputCompleter.new(Readline).call "a.to_s.", :target => Pry.binding_for(Object.new) }.not_to raise_error
-    end
+  it "should not crash if there's a Module that has a symbolic name." do
+    skip unless Pry::Helpers::Platform.jruby?
+    expect { Pry::InputCompleter.new(Readline).call "a.to_s.", target: Pry.binding_for(Object.new) }.not_to raise_error
   end
 
   it 'should take parenthesis and other characters into account for symbols' do
-    expect { Pry::InputCompleter.new(Readline).call ":class)", :target => Pry.binding_for(Object.new) }.not_to raise_error
+    expect { Pry::InputCompleter.new(Readline).call ":class)", target: Pry.binding_for(Object.new) }.not_to raise_error
   end
 
   it 'should complete instance variables' do
@@ -61,12 +58,9 @@ describe Pry::InputCompleter do
     # Complete class variables.
     b = Pry.binding_for(object.class)
     completer_test(b).call('@@number', '@@number.class')
-
   end
 
-
   it 'should complete for stdlib symbols' do
-
     o = Object.new
     # Regexp
     completer_test(o).call('/foo/.extend')
@@ -115,7 +109,7 @@ describe Pry::InputCompleter do
     completer_test(binding).call('o.foo')
 
     # trailing slash
-    expect(Pry::InputCompleter.new(Readline).call('Mod2/', :target => Pry.binding_for(Mod)).include?('Mod2/')).to   eq(true)
+    expect(Pry::InputCompleter.new(Readline).call('Mod2/', target: Pry.binding_for(Mod)).include?('Mod2/')).to eq(true)
   end
 
   it 'should complete for arbitrary scopes' do
@@ -130,7 +124,7 @@ describe Pry::InputCompleter do
       Con = :constant
     end
 
-    pry = Pry.new(:target => Baz)
+    pry = Pry.new(target: Baz)
     pry.push_binding(Bar)
 
     b = Pry.binding_for(Bar)
@@ -139,7 +133,6 @@ describe Pry::InputCompleter do
   end
 
   it 'should complete for stdlib symbols' do
-
     o = Object.new
     # Regexp
     completer_test(o).call('/foo/.extend')
@@ -188,7 +181,7 @@ describe Pry::InputCompleter do
     completer_test(binding).call('o.foo')
 
     # trailing slash
-    expect(Pry::InputCompleter.new(Readline).call('Mod2/', :target => Pry.binding_for(Mod)).include?('Mod2/')).to   eq(true)
+    expect(Pry::InputCompleter.new(Readline).call('Mod2/', target: Pry.binding_for(Mod)).include?('Mod2/')).to eq(true)
   end
 
   it 'should complete for arbitrary scopes' do
@@ -203,7 +196,7 @@ describe Pry::InputCompleter do
       Con = :constant
     end
 
-    pry = Pry.new(:target => Baz)
+    pry = Pry.new(target: Baz)
     pry.push_binding(Bar)
 
     b = Pry.binding_for(Bar)
@@ -213,7 +206,7 @@ describe Pry::InputCompleter do
 
   it 'should not return nil in its output' do
     pry = Pry.new
-    expect(Pry::InputCompleter.new(Readline, pry).call("pry.", :target => binding)).not_to include nil
+    expect(Pry::InputCompleter.new(Readline, pry).call("pry.", target: binding)).not_to include nil
   end
 
   it 'completes expressions with all available methods' do
@@ -225,10 +218,12 @@ describe Pry::InputCompleter do
     completer_test(self, nil, false).call("[].size.parse_printf_format")
   end
 
-  if !Pry::Helpers::BaseHelpers.jruby?
+  unless Pry::Helpers::Platform.jruby?
     # Classes that override .hash are still hashable in JRuby, for some reason.
     it 'ignores methods from modules that override Object#hash incompatibly' do
-      _m = Module.new do
+      # skip unless Pry::Helpers::Platform.jruby?
+
+      m = Module.new do
         def self.hash(a, b)
         end
 
@@ -236,7 +231,7 @@ describe Pry::InputCompleter do
         end
       end
 
-      completer_test(self, nil, false).call("[].size.aaaa")
+      completer_test(m, nil, false).call("[].size.aaaa")
     end
   end
 end
