@@ -10,7 +10,7 @@ describe Pry::Editor do
     # OS-specific tempdir name. For GNU/Linux it's "tmp", for Windows it's
     # something "Temp".
     @tf_dir =
-      if Pry::Helpers::BaseHelpers.mri_19?
+      if Pry::Helpers::Platform.mri_19?
         Pathname.new(Dir::Tmpname.tmpdir)
       else
         Pathname.new(Dir.tmpdir)
@@ -21,26 +21,16 @@ describe Pry::Editor do
     @editor = Pry::Editor.new(Pry.new)
   end
 
-  unless Pry::Helpers::BaseHelpers.windows?
-    describe "build_editor_invocation_string" do
-      it 'should shell-escape files' do
-        invocation_str = @editor.build_editor_invocation_string(@tf_path, 5, true)
-        expect(invocation_str).to match(/#@tf_dir.+hello\\ world\.rb/)
-      end
+  describe "build_editor_invocation_string", skip: !Pry::Helpers::Platform.windows? do
+    it 'should shell-escape files' do
+      invocation_str = @editor.build_editor_invocation_string(@tf_path, 5, true)
+      expect(invocation_str).to match(/#@tf_dir.+hello\\ world\.rb/)
     end
   end
 
   describe "build_editor_invocation_string on windows" do
     before do
-      class Pry::Editor
-        def windows?; true; end
-      end
-    end
-
-    after do
-      class Pry::Editor
-        undef windows?
-      end
+      allow(Pry::Helpers::Platform).to receive(:windows?).and_return(true)
     end
 
     it "should not shell-escape files" do
@@ -51,7 +41,7 @@ describe Pry::Editor do
 
   describe 'invoke_editor with a proc' do
     it 'should not shell-escape files' do
-      editor = Pry::Editor.new(Pry.new(editor: proc{ |file, line, blocking|
+      editor = Pry::Editor.new(Pry.new(editor: proc { |file, line, blocking|
         @file = file
         nil
       }))
