@@ -1,6 +1,6 @@
 require 'bundler/setup'
-require 'pry/testable'
 Bundler.require :default, :test
+require 'pry/testable'
 require_relative 'spec_helpers/mock_pry'
 require_relative 'spec_helpers/repl_tester'
 
@@ -20,10 +20,11 @@ end.new(nil)
 
 # to help with tracking down bugs that cause an infinite loop in the test suite
 if ENV["SET_TRACE_FUNC"]
-  require 'set_trace' if Pry::Helpers::BaseHelpers.rbx?
-  set_trace_func proc { |event, file, line, id, binding, classname|
+  set_trace_func(
+    proc { |event, file, line, id, binding, classname|
      STDERR.printf "%8s %s:%-2d %10s %8s\n", event, file, line, id, classname
-  }
+    }
+  )
 end
 
 RSpec.configure do |config|
