@@ -5,7 +5,7 @@ describe Pry do
   before do
     Pry.history.clear
 
-    @saved_history = "1\n2\n3\n"
+    @saved_history = "1\n2\n3\ninvalid\0 line\n"
 
     Pry.history.loader = proc do |&blk|
       @saved_history.lines.each { |l| blk.call(l) }
@@ -28,6 +28,12 @@ describe Pry do
       expect(Pry.history.to_a.grep('_ += 1').count).to eq 1
     end
 
+    it "does not record lines that contain a NULL byte" do
+      c = Pry.history.to_a.count
+      Pry.history << "a\0b"
+      expect(Pry.history.to_a.count).to eq c
+    end
+
     it "does not record empty lines" do
       c = Pry.history.to_a.count
       Pry.history << ''
@@ -129,9 +135,9 @@ describe Pry do
   describe "saving to a file" do
     before do
       @histfile = Tempfile.new(["pryhistory", "txt"])
-      @history = Pry::History.new(:file_path => @histfile.path)
+      @history = Pry::History.new(file_path: @histfile.path)
       Pry.config.history.should_save = true
-      @history.pusher = proc{ }
+      @history.pusher = proc {}
     end
 
     after do
@@ -146,7 +152,7 @@ describe Pry do
 
     it "interleaves lines from many places" do
       @history.push "5"
-      File.open(@histfile.path, 'a'){ |f| f.puts "6" }
+      File.open(@histfile.path, 'a') { |f| f.puts "6" }
       @history.push "7"
 
       expect(File.read(@histfile.path)).to eq "5\n6\n7\n"
@@ -181,4 +187,24 @@ describe Pry do
       expect { history.push 'a line' }.to raise_error error
     end
   end
+
+  describe "file io errors" do
+    let(:history) { Pry::History.new(file_path: file_path) }
+    let(:file_path) { Tempfile.new("pry_history_spec").path }
+
+    [Errno::EACCES, Errno::ENOENT].each do |error_class|
+      it "handles #{ error_class } failure to read from history" do
+        expect(File).to receive(:foreach).and_raise(error_class)
+        expect(history).to receive(:warn).with(/Unable to read history file:/)
+        expect { history.load }.to_not raise_error
+      end
+
+      it "handles #{ error_class } failure to write history" do
+        Pry.config.history.should_save = true
+        expect(File).to receive(:open).with(file_path, "a", 0600).and_raise(error_class)
+        expect(history).to receive(:warn).with(/Unable to write history file:/)
+        expect { history.push("anything") }.to_not raise_error
+      end
+    end
+  end
 end
