@@ -19,12 +19,12 @@ describe Pry::Hooks do
     end
 
     it 'should create a new hook with a block' do
-      @hooks.add_hook(:test_hook, :my_name) { }
+      @hooks.add_hook(:test_hook, :my_name) {}
       expect(@hooks.hook_count(:test_hook)).to eq 1
     end
 
     it 'should create a new hook with a callable' do
-      @hooks.add_hook(:test_hook, :my_name, proc { })
+      @hooks.add_hook(:test_hook, :my_name, proc {})
       expect(@hooks.hook_count(:test_hook)).to eq 1
     end
 
@@ -138,7 +138,6 @@ describe Pry::Hooks do
           expect(h2.get_hook(:test_hook3, :testing)).to eq nil
         end
       end
-
     end
   end
 
@@ -169,19 +168,18 @@ describe Pry::Hooks do
 
       expect(hooks_dup.get_hook(:test_hook, :testing2)).not_to eq @hooks.get_hook(:test_hook, :testing2)
     end
-
   end
 
   describe "getting hooks" do
     describe "get_hook" do
       it 'should return the correct requested hook' do
-        run = false
-        fun = false
-        @hooks.add_hook(:test_hook, :my_name) { run = true }
-        @hooks.add_hook(:test_hook, :my_name2) { fun = true }
+        run1 = false
+        run2 = false
+        @hooks.add_hook(:test_hook, :my_name) { run1 = true }
+        @hooks.add_hook(:test_hook, :my_name2) { run2 = true }
         @hooks.get_hook(:test_hook, :my_name).call
-        expect(run).to eq true
-        expect(fun).to eq false
+        expect(run1).to eq true
+        expect(run2).to eq false
       end
 
       it 'should return nil if hook does not exist' do
@@ -209,9 +207,9 @@ describe Pry::Hooks do
 
   describe "clearing all hooks for an event" do
     it 'should clear all hooks' do
-      @hooks.add_hook(:test_hook, :my_name) { }
-      @hooks.add_hook(:test_hook, :my_name2) { }
-      @hooks.add_hook(:test_hook, :my_name3) { }
+      @hooks.add_hook(:test_hook, :my_name) {}
+      @hooks.add_hook(:test_hook, :my_name2) {}
+      @hooks.add_hook(:test_hook, :my_name3) {}
       @hooks.clear_event_hooks(:test_hook)
       expect(@hooks.hook_count(:test_hook)).to eq 0
     end
@@ -314,7 +312,7 @@ describe Pry::Hooks do
         Pry.config.hooks.add_hook(:when_started, :test_hook) { |target, opt, _| options = opt }
 
         redirect_pry_io(StringIO.new("exit"), StringIO.new) do
-          Pry.start binding, :hello => :baby
+          Pry.start binding, hello: :baby
         end
 
         expect(options[:hello]).to eq :baby
@@ -323,13 +321,12 @@ describe Pry::Hooks do
       end
 
       describe "target" do
-
         it 'should yield the target, as a binding ' do
           b = nil
           Pry.config.hooks.add_hook(:when_started, :test_hook) { |target, opt, _| b = target }
 
           redirect_pry_io(StringIO.new("exit"), StringIO.new) do
-            Pry.start 5, :hello => :baby
+            Pry.start 5, hello: :baby
           end
 
           expect(b.is_a?(Binding)).to eq true
@@ -341,7 +338,7 @@ describe Pry::Hooks do
           Pry.config.hooks.add_hook(:when_started, :test_hook) { |target, opt, _| b = target }
 
           redirect_pry_io(StringIO.new("exit"), StringIO.new) do
-            Pry.start 5, :hello => :baby
+            Pry.start 5, hello: :baby
           end
 
           expect(b.eval('self')).to eq 5
@@ -356,13 +353,12 @@ describe Pry::Hooks do
         Pry.config.hooks.add_hook(:when_started, :test_hook) { |target, opt, _pry_| _pry_.binding_stack = [Pry.binding_for(o)] }
 
         redirect_pry_io(InputTester.new("@value = true","exit-all")) do
-          Pry.start binding, :hello => :baby
+          Pry.start binding, hello: :baby
         end
 
         expect(o.value).to eq true
         Pry.config.hooks.delete_hook(:when_started, :test_hook)
       end
-
     end
 
     describe "after_session hook" do
@@ -377,7 +373,7 @@ describe Pry::Hooks do
 
         begin
           redirect_pry_io(StringIO.new("raise great_escape"), StringIO.new) do
-            Pry.start o, :hooks => Pry::Hooks.new.add_hook(:after_session, :cleanup) { array = nil }
+            Pry.start o, hooks: Pry::Hooks.new.add_hook(:after_session, :cleanup) { array = nil }
           end
         rescue => ex
           exception = ex
@@ -399,7 +395,7 @@ describe Pry::Hooks do
           it 'should replace input code with code determined by hook' do
             hooks = Pry::Hooks.new.add_hook(:before_eval, :quirk) { |code, pry| code.replace(":little_duck") }
             redirect_pry_io(InputTester.new(":jemima", "exit-all"), out = StringIO.new) do
-              Pry.start(self, :hooks => hooks)
+              Pry.start(self, hooks: hooks)
             end
             expect(out.string).to match(/little_duck/)
             expect(out.string).not_to match(/jemima/)
@@ -417,19 +413,18 @@ describe Pry::Hooks do
             hooks = Pry::Hooks.new.add_hook(:before_eval, :quirk) { |code, pry| code.replace(":little_duck") }
 
             redirect_pry_io(InputTester.new("how-do-you-like-your-blue-eyed-boy-now-mister-death", "exit-all"), out = StringIO.new) do
-              Pry.start(self, :hooks => hooks, :commands => commands)
+              Pry.start(self, hooks: hooks, commands: commands)
             end
             expect(out.string).to match(/in hours of bitterness i imagine balls of sapphire, of metal/)
             expect(out.string).not_to match(/little_duck/)
           end
         end
-
       end
 
       describe "exceptions" do
         before do
-          Pry.config.hooks.add_hook(:after_eval, :baddums){ raise "Baddums" }
-          Pry.config.hooks.add_hook(:after_eval, :simbads){ raise "Simbads" }
+          Pry.config.hooks.add_hook(:after_eval, :baddums) { raise "Baddums" }
+          Pry.config.hooks.add_hook(:after_eval, :simbads) { raise "Simbads" }
         end
 
         after do
@@ -454,8 +449,8 @@ describe Pry::Hooks do
     end
 
     it 'should only allow one anonymous hook to exist' do
-      @hooks.add_hook(:test_hook, nil) {  }
-      @hooks.add_hook(:test_hook, nil) {  }
+      @hooks.add_hook(:test_hook, nil) {}
+      @hooks.add_hook(:test_hook, nil) {}
       expect(@hooks.hook_count(:test_hook)).to eq 1
     end
 
@@ -469,5 +464,4 @@ describe Pry::Hooks do
       expect(x).to eq 2
     end
   end
-
 end
