@@ -21,43 +21,63 @@ describe Pry::Method do
     end
 
     it 'should look up instance methods first even if methods available and no options provided' do
-      klass = Class.new { def hello; end; def self.hello; end  }
+      klass = Class.new do
+        def hello; end
+
+        def self.hello; end
+      end
       meth = Pry::Method.from_str(:hello, Pry.binding_for(klass))
       expect(meth).to eq klass.instance_method(:hello)
     end
 
     it 'should look up instance methods if "instance-methods"  option provided' do
-      klass = Class.new { def hello; end; def self.hello; end  }
+      klass = Class.new do
+        def hello; end
+
+        def self.hello; end
+      end
       meth = Pry::Method.from_str(:hello, Pry.binding_for(klass), {"instance-methods" => true})
       expect(meth).to eq klass.instance_method(:hello)
     end
 
     it 'should look up methods if :methods  option provided' do
-      klass = Class.new { def hello; end; def self.hello; end  }
-      meth = Pry::Method.from_str(:hello, Pry.binding_for(klass), {:methods => true})
+      klass = Class.new do
+        def hello; end
+
+        def self.hello; end
+      end
+      meth = Pry::Method.from_str(:hello, Pry.binding_for(klass), {methods: true})
       expect(meth).to eq klass.method(:hello)
     end
 
     it 'should look up instance methods using the Class#method syntax' do
-      klass = Class.new { def hello; end; def self.hello; end  }
+      klass = Class.new do
+        def hello; end
+
+        def self.hello; end
+      end
       meth = Pry::Method.from_str("klass#hello", Pry.binding_for(binding))
       expect(meth).to eq klass.instance_method(:hello)
     end
 
     it 'should look up methods using the object.method syntax' do
-      klass = Class.new { def hello; end; def self.hello; end  }
+      klass = Class.new do
+        def hello; end
+
+        def self.hello; end
+      end
       meth = Pry::Method.from_str("klass.hello", Pry.binding_for(binding))
       expect(meth).to eq klass.method(:hello)
     end
 
     it 'should NOT look up instance methods using the Class#method syntax if no instance methods defined' do
-      _klass = Class.new { def self.hello; end  }
+      _klass = Class.new { def self.hello; end }
       meth = Pry::Method.from_str("_klass#hello", Pry.binding_for(binding))
       expect(meth).to eq nil
     end
 
     it 'should NOT look up methods using the object.method syntax if no methods defined' do
-      _klass = Class.new { def hello; end  }
+      _klass = Class.new { def hello; end }
       meth = Pry::Method.from_str("_klass.hello", Pry.binding_for(binding))
       expect(meth).to eq nil
     end
@@ -87,7 +107,7 @@ describe Pry::Method do
     end
 
     it 'should look up methods using instance::bar syntax' do
-      _klass = Class.new{ def self.meth; Class.new; end }
+      _klass = Class.new { def self.meth; Class.new; end }
       meth = Pry::Method.from_str("_klass::meth", Pry.binding_for(binding))
       expect(meth.name).to eq "meth"
     end
@@ -99,7 +119,7 @@ describe Pry::Method do
 
   describe '.from_binding' do
     it 'should be able to pick a method out of a binding' do
-      expect(Pry::Method.from_binding(Class.new{ def self.foo; binding; end }.foo).name).to eq "foo"
+      expect(Pry::Method.from_binding(Class.new { def self.foo; binding; end }.foo).name).to eq "foo"
     end
 
     it 'should NOT find a method from the toplevel binding' do
@@ -118,24 +138,27 @@ describe Pry::Method do
       expect(m.name).to eq "bar"
     end
 
-    # Our source_location trick doesn't work, due to https://github.com/rubinius/rubinius/issues/953
-    unless Pry::Helpers::BaseHelpers.rbx?
-       it 'should find the super method correctly' do
-        a = Class.new{ def gag33; binding; end; def self.line; __LINE__; end }
-        b = Class.new(a){ def gag33; super; end }
+    it 'should find the super method correctly' do
+      # rubocop:disable Layout/EmptyLineBetweenDefs
+      a = Class.new { def gag33; binding; end; def self.line; __LINE__; end }
+      # rubocop:enable Layout/EmptyLineBetweenDefs
 
-        g = b.new.gag33
-        m = Pry::Method.from_binding(g)
+      b = Class.new(a) { def gag33; super; end }
 
-        expect(m.owner).to eq a
-        expect(m.source_line).to eq a.line
-        expect(m.name).to eq "gag33"
-      end
+      g = b.new.gag33
+      m = Pry::Method.from_binding(g)
+
+      expect(m.owner).to eq a
+      expect(m.source_line).to eq a.line
+      expect(m.name).to eq "gag33"
     end
 
     it 'should find the right method if a super method exists' do
-      a = Class.new{ def gag; binding; end; }
-      b = Class.new(a){ def gag; super; binding; end; def self.line; __LINE__; end }
+      a = Class.new { def gag; binding; end; }
+
+      # rubocop:disable Layout/EmptyLineBetweenDefs
+      b = Class.new(a) { def gag; super; binding; end; def self.line; __LINE__; end }
+      # rubocop:enable Layout/EmptyLineBetweenDefs
 
       m = Pry::Method.from_binding(b.new.gag)
 
@@ -144,16 +167,17 @@ describe Pry::Method do
       expect(m.name).to eq "gag"
     end
 
-    # Temporarily disabled to work around rubinius/rubinius#2871.
-    unless Pry::Helpers::BaseHelpers.rbx?
-      it "should find the right method from a BasicObject" do
-        a = Class.new(BasicObject) { def gag; ::Kernel.binding; end; def self.line; __LINE__; end }
-
-        m = Pry::Method.from_binding(a.new.gag)
-        expect(m.owner).to eq a
-        expect(m.source_file).to eq __FILE__
-        expect(m.source_line).to eq a.line
+    it "should find the right method from a BasicObject" do
+      # rubocop:disable Layout/EmptyLineBetweenDefs
+      a = Class.new(BasicObject) do
+        def gag; ::Kernel.binding; end; def self.line; __LINE__; end
       end
+      # rubocop:enable Layout/EmptyLineBetweenDefs
+
+      m = Pry::Method.from_binding(a.new.gag)
+      expect(m.owner).to eq a
+      expect(m.source_file).to eq __FILE__
+      expect(m.source_line).to eq a.line
     end
 
     it 'should find the right method even if it was renamed and replaced' do
@@ -174,8 +198,8 @@ describe Pry::Method do
 
   describe 'super' do
     it 'should be able to find the super method on a bound method' do
-      a = Class.new{ def rar; 4; end }
-      b = Class.new(a){ def rar; super; end }
+      a = Class.new { def rar; 4; end }
+      b = Class.new(a) { def rar; super; end }
 
       obj = b.new
 
@@ -185,40 +209,40 @@ describe Pry::Method do
     end
 
     it 'should be able to find the super method of an unbound method' do
-      a = Class.new{ def rar; 4; end }
-      b = Class.new(a){ def rar; super; end }
+      a = Class.new { def rar; 4; end }
+      b = Class.new(a) { def rar; super; end }
 
       zuper = Pry::Method(b.instance_method(:rar)).super
       expect(zuper.owner).to eq a
     end
 
     it 'should return nil if no super method exists' do
-      a = Class.new{ def rar; super; end }
+      a = Class.new { def rar; super; end }
 
       expect(Pry::Method(a.instance_method(:rar)).super).to eq nil
     end
 
     it 'should be able to find super methods defined on modules' do
-      m = Module.new{ def rar; 4; end }
-      a = Class.new{ def rar; super; end; include m }
+      m = Module.new { def rar; 4; end }
+      a = Class.new { def rar; super; end; include m }
 
       zuper = Pry::Method(a.new.method(:rar)).super
       expect(zuper.owner).to eq m
     end
 
     it 'should be able to find super methods defined on super-classes when there are modules in the way' do
-      a = Class.new{ def rar; 4; end }
-      m = Module.new{ def mooo; 4; end }
-      b = Class.new(a){ def rar; super; end; include m }
+      a = Class.new { def rar; 4; end }
+      m = Module.new { def mooo; 4; end }
+      b = Class.new(a) { def rar; super; end; include m }
 
       zuper = Pry::Method(b.new.method(:rar)).super
       expect(zuper.owner).to eq a
     end
 
     it 'should be able to jump up multiple levels of bound method, even through modules' do
-      a = Class.new{ def rar; 4; end }
-      m = Module.new{ def rar; 4; end }
-      b = Class.new(a){ def rar; super; end; include m }
+      a = Class.new { def rar; 4; end }
+      m = Module.new { def rar; 4; end }
+      b = Class.new(a) { def rar; super; end; include m }
 
       zuper = Pry::Method(b.new.method(:rar)).super
       expect(zuper.owner).to eq m
@@ -232,7 +256,7 @@ describe Pry::Method do
     end
 
     it 'should be able to find public instance methods defined in a class' do
-      @class = Class.new{ def meth; 1; end }
+      @class = Class.new { def meth; 1; end }
       should_find_method('meth')
     end
 
@@ -248,23 +272,31 @@ describe Pry::Method do
     end
 
     it 'should be able to find instance methods defined in a super-class' do
-      @class = Class.new(Class.new{ def meth; 1; end }) {}
+      @class = Class.new(Class.new { def meth; 1; end }) {}
       should_find_method('meth')
     end
 
     it 'should be able to find instance methods defined in modules included into this class' do
-      @class = Class.new{ include Module.new{ def meth; 1; end; } }
+      @class = Class.new do
+        include(Module.new { def meth; 1; end })
+      end
       should_find_method('meth')
     end
 
     it 'should be able to find instance methods defined in modules included into super-classes' do
-      @class = Class.new(Class.new{ include Module.new{ def meth; 1; end; } })
+      super_class = Class.new do
+        include(Module.new { def meth; 1; end })
+      end
+      @class = Class.new(super_class)
       should_find_method('meth')
     end
 
     it 'should attribute overridden methods to the sub-class' do
-      @class = Class.new(Class.new{ include Module.new{ def meth; 1; end; } }) { def meth; 2; end }
-      expect(Pry::Method.all_from_class(@class).detect{ |x| x.name == 'meth' }.owner).to eq @class
+      super_class = Class.new do
+        include(Module.new { def meth; 1; end })
+      end
+      @class = Class.new(super_class) { def meth; 2; end }
+      expect(Pry::Method.all_from_class(@class).detect { |x| x.name == 'meth' }.owner).to eq @class
     end
 
     it 'should be able to find methods defined on a singleton class' do
@@ -273,7 +305,7 @@ describe Pry::Method do
     end
 
     it 'should be able to find methods on super-classes when given a singleton class' do
-      @class = (class << Class.new{ def meth; 1; end}.new; self; end)
+      @class = (class << Class.new { def meth; 1; end }.new; self; end)
       should_find_method('meth')
     end
   end
@@ -285,12 +317,14 @@ describe Pry::Method do
       end
 
       it "should find methods defined in the object's class" do
-        @obj = Class.new{ def meth; 1; end }.new
+        @obj = Class.new { def meth; 1; end }.new
         should_find_method('meth')
       end
 
       it "should find methods defined in modules included into the object's class" do
-        @obj = Class.new{ include Module.new{ def meth; 1; end } }.new
+        @obj = Class.new {
+          include(Module.new { def meth; 1; end })
+        }.new
         should_find_method('meth')
       end
 
@@ -302,7 +336,7 @@ describe Pry::Method do
 
       it "should find methods in modules included into the object's singleton class" do
         @obj = Object.new
-        @obj.extend Module.new{ def meth; 1; end }
+        @obj.extend(Module.new { def meth; 1; end })
         should_find_method('meth')
       end
 
@@ -312,12 +346,16 @@ describe Pry::Method do
       end
 
       it "should not find methods defined on the classes singleton class" do
-        @obj = Class.new{ class << self; def meth; 1; end; end }.new
+        @obj = Class.new { class << self; def meth; 1; end; end }.new
         expect(Pry::Method.all_from_obj(@obj).map(&:name)).not_to include 'meth'
       end
 
       it "should work in the face of an overridden send" do
-        @obj = Class.new{ def meth; 1; end; def send; raise EOFError; end }.new
+        @obj = Class.new {
+          def meth; 1; end
+
+          def send; raise EOFError; end
+        }.new
         should_find_method('meth')
       end
     end
@@ -328,22 +366,24 @@ describe Pry::Method do
       end
 
       it "should find methods defined in the class' singleton class" do
-        @class = Class.new{ class << self; def meth; 1; end; end }
+        @class = Class.new { class << self; def meth; 1; end; end }
         should_find_method('meth')
       end
 
       it "should find methods defined on modules extended into the class" do
-        @class = Class.new{ extend Module.new{ def meth; 1; end; } }
+        @class = Class.new do
+          extend(Module.new { def meth; 1; end })
+        end
         should_find_method('meth')
       end
 
       it "should find methods defined on the singleton class of super-classes" do
-        @class = Class.new(Class.new{ class << self; def meth; 1; end; end })
+        @class = Class.new(Class.new { class << self; def meth; 1; end; end })
         should_find_method('meth')
       end
 
       it "should not find methods defined within the class" do
-        @class = Class.new{ def meth; 1; end }
+        @class = Class.new { def meth; 1; end }
         expect(Pry::Method.all_from_obj(@class).map(&:name)).not_to include 'meth'
       end
 
@@ -358,18 +398,23 @@ describe Pry::Method do
       end
 
       it "should attribute overridden methods to the sub-class' singleton class" do
-        @class = Class.new(Class.new{ class << self; def meth; 1; end; end }) { class << self; def meth; 1; end; end }
-        expect(Pry::Method.all_from_obj(@class).detect{ |x| x.name == 'meth' }.owner).to eq(class << @class; self; end)
+        @class = Class.new(Class.new { class << self; def meth; 1; end; end }) { class << self; def meth; 1; end; end }
+        expect(Pry::Method.all_from_obj(@class).detect { |x| x.name == 'meth' }.owner).to eq(class << @class; self; end)
       end
 
       it "should attrbute overridden methods to the class not the module" do
-        @class = Class.new { class << self; def meth; 1; end; end; extend Module.new{ def meth; 1; end; } }
-        expect(Pry::Method.all_from_obj(@class).detect{ |x| x.name == 'meth' }.owner).to eq(class << @class; self; end)
+        @class = Class.new do
+          class << self
+            def meth; 1; end
+          end
+          extend(Module.new { def meth; 1; end })
+        end
+        expect(Pry::Method.all_from_obj(@class).detect { |x| x.name == 'meth' }.owner).to eq(class << @class; self; end)
       end
 
       it "should attribute overridden methods to the relevant singleton class in preference to Class" do
         @class = Class.new { class << self; def allocate; 1; end; end }
-        expect(Pry::Method.all_from_obj(@class).detect{ |x| x.name == 'allocate' }.owner).to eq(class << @class; self; end)
+        expect(Pry::Method.all_from_obj(@class).detect { |x| x.name == 'allocate' }.owner).to eq(class << @class; self; end)
       end
     end
 
@@ -389,11 +434,9 @@ describe Pry::Method do
         class Bottom < Lower; extend O; end
       end
 
-
       def eigen_class(obj); class << obj; self; end; end
 
       it "should look at a class and then its superclass" do
-
         expect(Pry::Method.instance_resolution_order(LS::Next)).to eq [LS::Next] + Pry::Method.instance_resolution_order(LS::Top)
       end
 
@@ -437,9 +480,9 @@ describe Pry::Method do
 
       it "should include the Pry::Method.instance_resolution_order of Class after the singleton classes" do
         expect(Pry::Method.resolution_order(LS::Top)).to eq(
-          [eigen_class(LS::Top), eigen_class(Object), eigen_class(BasicObject),
-           *Pry::Method.instance_resolution_order(Class)]
-        )
+                                                           [eigen_class(LS::Top), eigen_class(Object), eigen_class(BasicObject),
+                                                            *Pry::Method.instance_resolution_order(Class)]
+                                                         )
       end
     end
   end
@@ -508,4 +551,53 @@ describe Pry::Method do
       expect(aliases).to eq Set.new(["include?", "member?", "has_key?"])
     end
   end
+
+  describe '.signature' do
+    before do
+      @class = Class.new {
+        def self.standard_arg(arg) end
+
+        def self.block_arg(&block) end
+
+        def self.rest(*splat) end
+
+        def self.optional(option = nil) end
+      }
+    end
+
+    it 'should print the name of regular args' do
+      signature = Pry::Method.new(@class.method(:standard_arg)).signature
+      expect(signature).to eq("standard_arg(arg)")
+    end
+
+    it 'should print the name of block args, with an & label' do
+      signature = Pry::Method.new(@class.method(:block_arg)).signature
+      expect(signature).to eq("block_arg(&block)")
+    end
+
+    it 'should print the name of additional args, with an * label' do
+      signature = Pry::Method.new(@class.method(:rest)).signature
+      expect(signature).to eq("rest(*splat)")
+    end
+
+    it 'should print the name of optional args, with =? after the arg name' do
+      signature = Pry::Method.new(@class.method(:optional)).signature
+      expect(signature).to eq("optional(option=?)")
+    end
+
+    # keyword args are only on >= Ruby 2.1
+    if Gem::Version.new(RUBY_VERSION) >= Gem::Version.new("2.1")
+      it 'should print the name of keyword args, with :? after the arg name' do
+        eval %{def @class.keyword(keyword_arg: "") end}
+        signature = Pry::Method.new(@class.method(:keyword)).signature
+        expect(signature).to eq("keyword(keyword_arg:?)")
+      end
+
+      it 'should print the name of keyword args, with : after the arg name' do
+        eval %{def @class.required_keyword(required_key:) end}
+        signature = Pry::Method.new(@class.method(:required_keyword)).signature
+        expect(signature).to eq("required_keyword(required_key:)")
+      end
+    end
+  end
 end
