@@ -17,10 +17,10 @@ describe Pry::REPL do
       output(/^RuntimeError: lorum/)
 
       if defined?(java)
-        input  'raise java.lang.Exception.new("foo")'
+        input 'raise java.lang.Exception.new("foo")'
         output(/Exception: foo/)
 
-        input  'raise java.io.IOException.new("bar")'
+        input 'raise java.io.IOException.new("bar")'
         output(/IOException: bar/)
       end
     end
@@ -67,11 +67,11 @@ describe Pry::REPL do
         output ''
         prompt(/10.*> $/)
 
-        input  '_pry_.binding_stack.pop'
+        input '_pry_.binding_stack.pop'
         output(/^=> #<Binding/)
         prompt(/main.*> $/)
 
-        input  '_pry_.binding_stack.pop'
+        input '_pry_.binding_stack.pop'
         output(/^=> #<Binding/)
         assert_exited
       end
@@ -86,7 +86,7 @@ describe Pry::REPL do
         end
       end
 
-      ReplTester.start(:commands => set) do
+      ReplTester.start(commands: set) do
         input  'def x'
         output ''
         prompt(/\*   $/)
@@ -121,4 +121,19 @@ describe Pry::REPL do
       $stdout = old_stdout
     end
   end
+
+  describe "autoindent" do
+    it "should raise no exception when indented with a tab" do
+      ReplTester.start(correct_indent: true, auto_indent: true) do
+        output = @pry.config.output
+        def output.tty?; true; end
+        input <<EOS
+loop do
+	break #note the tab here
+end
+EOS
+        output("do\n  break #note the tab here\nend\n\e[1B\e[0G=> nil")
+      end
+    end
+  end
 end
