@@ -52,11 +52,11 @@ describe Pry do
     end
 
     it 'should raise an error for binding.pry' do
-      expect{binding.pry}.to raise_error(RuntimeError)
+      expect { binding.pry }.to raise_error(RuntimeError)
     end
 
     it 'should raise an error for Pry.start' do
-      expect{Pry.start}.to raise_error(RuntimeError)
+      expect { Pry.start }.to raise_error(RuntimeError)
     end
   end
 
@@ -72,11 +72,10 @@ describe Pry do
   end
 
   describe "Pry.binding_for" do
-
     # regression test for burg's bug (see git history)
     it "Should not error when object doesn't have a valid == method" do
       o = Object.new
-      def o.==(other)
+      def o.==(_other)
         raise
       end
 
@@ -171,13 +170,13 @@ describe Pry do
 
       it 'should be able to evaluate exceptions normally' do
         was_called = false
-        mock_pry("RuntimeError.new", :exception_handler => proc{ was_called = true })
+        mock_pry("RuntimeError.new", exception_handler: proc { was_called = true })
         expect(was_called).to eq false
       end
 
       it 'should notice when exceptions are raised' do
         was_called = false
-        mock_pry("raise RuntimeError", :exception_handler => proc{ was_called = true })
+        mock_pry("raise RuntimeError", exception_handler: proc { was_called = true })
         expect(was_called).to eq true
       end
 
@@ -243,7 +242,7 @@ describe Pry do
 
           o = Object.new
 
-          Pry.start(o, :input => input, :output => StringIO.new)
+          Pry.start(o, input: input, output: StringIO.new)
 
           expect(o.instance_variable_get(:@x)).to eq 10
         end
@@ -273,7 +272,7 @@ describe Pry do
           t.eval "42"
           res = t.eval "_out_"
 
-          expect(res).to be_a_kind_of Pry::HistoryArray
+          expect(res).to be_a_kind_of(Pry::Ring)
           expect(res[1..2]).to eq [:foo, 42]
         end
 
@@ -283,7 +282,7 @@ describe Pry do
           t.eval "42"
           res = t.eval "_in_"
 
-          expect(res).to be_a_kind_of Pry::HistoryArray
+          expect(res).to be_a_kind_of(Pry::Ring)
           expect(res[1..2]).to eq [":foo\n", "42\n"]
         end
 
@@ -292,7 +291,7 @@ describe Pry do
         end
 
         it 'can change the size of the history arrays' do
-          expect(pry_tester(:memory_size => 1000).eval("[_out_, _in_].map(&:max_size)")).to eq [1000, 1000]
+          expect(pry_tester(memory_size: 1000).eval("[_out_, _in_].map(&:max_size)")).to eq [1000, 1000]
         end
 
         it 'store exceptions' do
@@ -312,7 +311,7 @@ describe Pry do
         # replacing the eval_string, so _ won't be modified without Pry doing
         # a REPL loop.
         it "should be set to the result of a command with :keep_retval" do
-          Pry::Commands.block_command '++', '', :keep_retval => true do |a|
+          Pry::Commands.block_command '++', '', keep_retval: true do |a|
             a.to_i + 1
           end
 
@@ -369,9 +368,9 @@ describe Pry do
         it 'should define a method on the class of an object when performing "def meth;end" inside an immediate value or Numeric' do
           # JRuby behaves different than CRuby here (seems it always has to some extent, see 'unless' below).
           # It didn't seem trivial to work around. Skip for now.
-          skip "JRuby incompatibility" if Pry::Helpers::BaseHelpers.jruby?
+          skip "JRuby incompatibility" if Pry::Helpers::Platform.jruby?
           [:test, 0, true, false, nil,
-              (0.0 unless Pry::Helpers::BaseHelpers.jruby?)].each do |val|
+              (0.0 unless Pry::Helpers::Platform.jruby?)].each do |val|
             pry_eval(val, "def hello; end");
             expect(val.class.instance_methods(false).map(&:to_sym).include?(:hello)).to eq true
           end
@@ -379,7 +378,6 @@ describe Pry do
       end
 
       describe "Object#pry" do
-
         after do
           Pry.reset_defaults
           Pry.config.color = false
@@ -408,7 +406,7 @@ describe Pry do
         end
 
         it "should raise if more than two arguments are passed to Object#pry" do
-          expect { pry(20, :quiet, :input => Readline) }.to raise_error ArgumentError
+          expect { pry(20, :quiet, input: Readline) }.to raise_error ArgumentError
         end
       end
 
@@ -425,11 +423,11 @@ describe Pry do
 
   describe 'setting custom options' do
     it 'does not raise for unrecognized options' do
-      expect { Pry.new(:custom_option => 'custom value') }.to_not raise_error
+      expect { Pry.new(custom_option: 'custom value') }.to_not raise_error
     end
 
     it 'correctly handles the :quiet option (#1261)' do
-      instance = Pry.new(:quiet => true)
+      instance = Pry.new(quiet: true)
       expect(instance.quiet?).to eq true
     end
   end
